// deployable objects script
//
// remote pulse sensor, remote motion sensor, remote turrets (indoor
// and outdoor), remote inventory station, remote ammo station
// Note: cameras are treated as grenades, not "regular" deployables

$TurretIndoorSpaceRadius  = 20;  // deployed turrets must be this many meters apart
$InventorySpaceRadius  = 20;  // deployed inventory must be this many meters apart
$TurretIndoorSphereRadius = 50;  // radius for turret frequency check
$TurretIndoorMaxPerSphere = 4;   // # of turrets allowed in above radius

$TurretOutdoorSpaceRadius  = 25;  // deployed turrets must be this many meters apart
$TurretOutdoorSphereRadius = 60;  // radius for turret frequency check
$TurretOutdoorMaxPerSphere = 4;   // # of turrets allowed in above radius

//$TeamDeployableMax[InventoryDeployable]      = 5;
//$TeamDeployableMax[TurretIndoorDeployable]   = 10;
//$TeamDeployableMax[TurretOutdoorDeployable]  = 10;
//$TeamDeployableMax[PulseSensorDeployable]    = 15;
//$TeamDeployableMax[MotionSensorDeployable]   = 15;

//$TeamDeployableMin[TurretIndoorDeployable] = 6;
//$TeamDeployableMin[TurretOutdoorDeployable] = 6;

$NotDeployableReason::None                      =  0;
$NotDeployableReason::MaxDeployed               =  1;
$NotDeployableReason::NoSurfaceFound            =  2;
$NotDeployableReason::SlopeTooGreat             =  3;
$NotDeployableReason::SelfTooClose              =  4;
$NotDeployableReason::ObjectTooClose            =  5;
$NotDeployableReason::NoTerrainFound            =  6;
$NotDeployableReason::NoInteriorFound           =  7;
$NotDeployableReason::TurretTooClose            =  8;
$NotDeployableReason::TurretSaturation          =  9;
$NotDeployableReason::SurfaceTooNarrow          =  10;
$NotDeployableReason::InventoryTooClose         =  11;

$MinDeployableDistance                       =  2.5;
$MaxDeployableDistance                       =  5;  //meters from body


//============================================= >Modification Zone<

function ForceFieldBareData::onAdd(%data, %obj)
{
   Parent::onAdd(%data, %obj);

   %pz = new PhysicalZone() {
      position = %obj.position;
      rotation = %obj.rotation;
      scale    = %obj.scale;
      polyhedron = "0.000000 1.0000000 0.0000000 1.0000000 0.0000000 0.0000000 0.0000000 -1.0000000 0.0000000 0.0000000 0.0000000 1.0000000";
      velocityMod  = 1.0;
      gravityMod   = 1.0;
      appliedForce = "0 0 0";
		ffield = %obj;
   };
	%pzGroup = nameToID("MissionCleanup/PZones");
	if(%pzGroup <= 0) {
		%pzGroup = new SimGroup("PZones");
		MissionCleanup.add(%pzGroup);
	}
	%pzGroup.add(%pz);
   %obj.pz = %pz;
   //MissionCleanupGroup.add(%pz);
}

// --------------------------------------------
// sound datablocks
// --------------------------------------------

datablock AudioProfile(TurretDeploySound)
{
   fileName = "fx/packs/turret_place.wav";
   description = AudioClose3d;
   preload = true;
};

datablock AudioProfile(SensorDeploySound)
{
   fileName = "fx/powered/sensor_activate.wav";
   description = AudioClose3d;
   preload = true;
};

datablock AudioProfile(MotionSensorDeploySound)
{
   fileName = "fx/powered/motion_sensor_activate.wav";
   description = AudioClose3d;
   preload = true;
};

datablock AudioProfile(StationDeploySound)
{
   fileName = "fx/packs/inventory_deploy.wav";
   description = AudioClose3d;
   preload = true;
};

// --------------------------------------------
// deployable debris definition

datablock DebrisData( DeployableDebris )
{
   explodeOnMaxBounce = false;

   elasticity = 0.40;
   friction = 0.5;

   lifetime = 17.0;
   lifetimeVariance = 0.0;

   minSpinSpeed = 60;
   maxSpinSpeed = 600;

   numBounces = 10;
   bounceVariance = 0;

   staticOnMaxBounce = true;

   useRadiusMass = true;
   baseRadius = 0.2;

   velocity = 5.0;
   velocityVariance = 2.5;
   
};             


// --------------------------------------------
// deployable inventory station

datablock StaticShapeData(DeployedStationInventory) : StaticShapeDamageProfile
{
   className = Station;
   shapeFile = "deploy_inventory.dts";
   maxDamage = 0.70;
   destroyedLevel = 0.70;
   disabledLevel = 0.42;
   explosion      = DeployablesExplosion;
      expDmgRadius = 8.0;
      expDamage = 0.35;
      expImpulse = 500.0;

   dynamicType = $TypeMasks::StationObjectType;
   isShielded = true;
   energyPerDamagePoint = 110;
   maxEnergy = 50;
   rechargeRate = 0.20;
   renderWhenDestroyed = false;
   doesRepair = true;

   deployedObject = true;

   cmdCategory = "DSupport";
   cmdIcon = CMDStationIcon;
   cmdMiniIconName = "commander/MiniIcons/com_inventory_grey";
   targetNameTag = 'Deployable';
   targetTypeTag = 'Station';

   debrisShapeName = "debris_generic_small.dts";
   debris = DeployableDebris;
   heatSignature = 0;
};

datablock ShapeBaseImageData(InventoryDeployableImage)
{
   mass = 15;
   emap = true;

   shapeFile = "pack_deploy_inventory.dts";
   item = InventoryDeployable;
   mountPoint = 1;
   offset = "0 0 0";
   deployed = DeployedStationInventory;
   heatSignature = 0;

   stateName[0] = "Idle";
   stateTransitionOnTriggerDown[0] = "Activate";

   stateName[1] = "Activate";
   stateScript[1] = "onActivate";
   stateTransitionOnTriggerUp[1] = "Idle";

   isLarge = true;
   maxDepSlope = 30;
   deploySound = StationDeploySound;

   flatMinDeployDis   = 1.0;
   flatMaxDeployDis   = 5.0;

   minDeployDis       = 2.5;
   maxDeployDis       = 5.0;
};

datablock ItemData(InventoryDeployable)
{
   className = Pack;
   catagory = "Deployables";
   shapeFile = "pack_deploy_inventory.dts";
   mass = 3.0;
   elasticity = 0.2;
   friction = 0.6;
   pickupRadius = 1;
   rotate = false;
   image = "InventoryDeployableImage";
   pickUpName = "an inventory pack";
   heatSignature = 0;

   computeCRC = true;
   emap = true;

};

// --------------------------------------------
// deployable motion sensor

datablock SensorData(DeployMotionSensorObj)
{
   detects = true;
   detectsUsingLOS = true;
   detectsActiveJammed = false;
   detectsPassiveJammed = true;
   detectsCloaked = true;
   detectionPings = false;
   detectMinVelocity = 2;
   detectRadius = 60;
};

datablock StaticShapeData(DeployedMotionSensor) : StaticShapeDamageProfile
{
   className = Sensor;
   shapeFile = "deploy_sensor_motion.dts";
   maxDamage = 0.6;
   destroyedLevel = 0.6;
   disabledLevel = 0.4;
   explosion = DeployablesExplosion;
   dynamicType = $TypeMasks::SensorObjectType;

   deployedObject = true;

   cmdCategory = "DSupport";
   cmdIcon = CMDSensorIcon;
   cmdMiniIconName = "commander/MiniIcons/com_deploymotionsensor";
   targetNameTag = 'Deployable Motion';
   targetTypeTag = 'Sensor';
   sensorData = DeployMotionSensorObj;
   sensorRadius = DeployMotionSensorObj.detectRadius;
   sensorColor = "9 136 255";
   deployAmbientThread = true;

   debrisShapeName = "debris_generic_small.dts";
   debris = DeployableDebris;
   heatSignature = 0;
};

datablock ShapeBaseImageData(MotionSensorDeployableImage)
{
   shapeFile = "pack_deploy_sensor_motion.dts";
   item = MotionSensorDeployable;
   mountPoint = 1;
   offset = "0 0 0";
   deployed = DeployedMotionSensor;

   stateName[0] = "Idle";
   stateTransitionOnTriggerDown[0] = "Activate";

   stateName[1] = "Activate";
   stateScript[1] = "onActivate";
   stateTransitionOnTriggerUp[1] = "Idle";

   maxDepSlope = 360;
   deploySound = MotionSensorDeploySound;
   emap = true;
   heatSignature = 1;

   minDeployDis                       =  0.5;
   maxDeployDis                       =  5.0;  //meters from body
};

datablock ItemData(MotionSensorDeployable)
{
   className = Pack;
   catagory = "Deployables";
   shapeFile = "pack_deploy_sensor_motion.dts";
   mass = 2.0;
   elasticity = 0.2;
   friction = 0.6;
   pickupRadius = 1;
   rotate = false;
   image = "MotionSensorDeployableImage";
   pickUpName = "a motion sensor pack";

   computeCRC = true;
   emap = true;
   heatSignature = 0;

   //maxSensors = 3;
   maxSensors = 2;
};

// --------------------------------------------
// deployable pulse sensor

datablock SensorData(DeployPulseSensorObj)
{
   detects = true;
   detectsUsingLOS = true;
   detectsPassiveJammed = false;
   detectsCloaked = false;
   detectionPings = true;
   detectRadius = 150;
};

datablock StaticShapeData(DeployedPulseSensor) : StaticShapeDamageProfile
{
   className = Sensor;
   shapeFile = "deploy_sensor_pulse.dts";
   maxDamage = 0.6;
   destroyedLevel = 0.6;
   disabledLevel = 0.4;
   explosion = DeployablesExplosion;
   dynamicType = $TypeMasks::SensorObjectType;

   deployedObject = true;

   cmdCategory = "DSupport";
   cmdIcon = CMDSensorIcon;
   cmdMiniIconName = "commander/MiniIcons/com_deploypulsesensor";
   targetNameTag = 'Deployable';
   targetTypeTag = 'Pulse Sensor';
   sensorData = DeployPulseSensorObj;
   sensorRadius = DeployPulseSensorObj.detectRadius;
   sensorColor = "255 194 9";
   deployAmbientThread = true;

   debrisShapeName = "debris_generic_small.dts";
   debris = DeployableDebris;
   heatSignature = 0;
};

datablock ShapeBaseImageData(PulseSensorDeployableImage)
{
   shapeFile = "pack_deploy_sensor_pulse.dts";
   item = PulseSensorDeployable;
   mountPoint = 1;
   offset = "0 0 0";
   deployed = DeployedPulseSensor;

   stateName[0] = "Idle";
   stateTransitionOnTriggerDown[0] = "Activate";

   stateName[1] = "Activate";
   stateScript[1] = "onActivate";
   stateTransitionOnTriggerUp[1] = "Idle";
   deploySound = SensorDeploySound;

   maxDepSlope = 40;
   emap = true;
   heatSignature = 0;

   minDeployDis                       =  0.5;
   maxDeployDis                       =  5.0;  //meters from body
};

datablock ItemData(PulseSensorDeployable)
{
   className = Pack;
   catagory = "Deployables";
   shapeFile = "pack_deploy_sensor_pulse.dts";
   mass = 2.0;
   elasticity = 0.2;
   friction = 0.6;
   pickupRadius = 1;
   rotate = false;
   image = "PulseSensorDeployableImage";
   pickUpName = "a pulse sensor pack";

   computeCRC = true;
   emap = true;

   maxSensors = 2;
};

// --------------------------------------------
// deployable outdoor turret

datablock ShapeBaseImageData(TurretOutdoorDeployableImage)
{
   mass = 15;

   shapeFile = "pack_deploy_turreto.dts";
   item = TurretOutdoorDeployable;
   mountPoint = 1;
   offset = "0 0 0";
   deployed = TurretDeployedOutdoor;

   stateName[0] = "Idle";
   stateTransitionOnTriggerDown[0] = "Activate";

   stateName[1] = "Activate";
   stateScript[1] = "onActivate";
   stateTransitionOnTriggerUp[1] = "Idle";

   maxDamage = 4.5;
   destroyedLevel = 4.5;
   disabledLevel = 4.0;

   isLarge = true;
   emap = true;

   maxDepSlope = 40;
   deploySound = TurretDeploySound;

   minDeployDis                       =  0.5;
   maxDeployDis                       =  5.0;  //meters from body
};

datablock ItemData(TurretOutdoorDeployable)
{
   className = Pack;
   catagory = "Deployables";
   shapeFile = "pack_deploy_turreto.dts";
   mass = 3.0;
   elasticity = 0.2;
   friction = 0.6;
   pickupRadius = 1;
   rotate = false;
   image = "TurretOutdoorDeployableImage";
   pickUpName = "a landspike turret pack";

   computeCRC = true;
   emap = true;

};

// --------------------------------------------
// deployable indoor turret (3 varieties -- floor, wall and ceiling)

datablock ShapeBaseImageData(TurretIndoorDeployableImage)
{
   mass = 15;

   shapeFile = "pack_deploy_turreti.dts";
   item = TurretIndoorDeployable;
   mountPoint = 1;
   offset = "0 0 0";

   stateName[0] = "Idle";
   stateTransitionOnTriggerDown[0] = "Activate";

   stateName[1] = "Activate";
   stateScript[1] = "onActivate";
   stateTransitionOnTriggerUp[1] = "Idle";

   isLarge = true;
   emap = true;

   maxDepSlope = 360;
   deploySound = TurretDeploySound;

   minDeployDis                       =  0.5;
   maxDeployDis                       =  5.0;  //meters from body
};

datablock ItemData(TurretIndoorDeployable)
{
   className = Pack;
   catagory = "Deployables";
   shapeFile = "pack_deploy_turreti.dts";
   mass = 3.0;
   elasticity = 0.2;
   friction = 0.6;
   pickupRadius = 1;
   rotate = false;
   image = "TurretIndoorDeployableImage";
   pickUpName = "a spider clamp turret pack";

   computeCRC = true;
   emap = true;

};

// --------------------------------------------
// miscellaneous yet handy functions

function posFromTransform(%transform)
{
   // the first three words of an object's transform are the object's position
   %position = getWord(%transform, 0) @ " " @ getWord(%transform, 1) @ " " @ getWord(%transform, 2);
   return %position;
}

function rotFromTransform(%transform)
{
   // the last four words of an object's transform are the object's rotation
   %rotation = getWord(%transform, 3) @ " " @ getWord(%transform, 4) @ " " @ getWord(%transform, 5) @ " " @ getWord(%transform, 6);
   return %rotation;
}

function posFromRaycast(%transform)
{
   // the 2nd, 3rd, and 4th words returned from a successful raycast call are the position of the point
   %position = getWord(%transform, 1) @ " " @ getWord(%transform, 2) @ " " @ getWord(%transform, 3);
   return %position;
}

function normalFromRaycast(%transform)
{
   // the 5th, 6th and 7th words returned from a successful raycast call are the normal of the surface
   %norm = getWord(%transform, 4) @ " " @ getWord(%transform, 5) @ " " @ getWord(%transform, 6);
   return %norm;
}

function addToDeployGroup(%object)
{
   // all deployables should go into a special group for AI purposes
   %depGroup = nameToID("MissionCleanup/Deployables");
   if(%depGroup <= 0) {
      %depGroup = new SimGroup("Deployables");
      MissionCleanup.add(%depGroup);
   }
   %depGroup.add(%object);
}

function Deployables::searchView(%obj, %searchRange, %mask)
{
   // get the eye vector and eye transform of the player
   %eyeVec   = %obj.getEyeVector();
   %eyeTrans = %obj.getEyeTransform();

   // extract the position of the player's camera from the eye transform (first 3 words)
   %eyePos = posFromTransform(%eyeTrans);

   // normalize the eye vector
   %nEyeVec = VectorNormalize(%eyeVec);

   // scale (lengthen) the normalized eye vector according to the search range
   %scEyeVec = VectorScale(%nEyeVec, %searchRange);

   // add the scaled & normalized eye vector to the position of the camera
   %eyeEnd = VectorAdd(%eyePos, %scEyeVec);

   // see if anything gets hit
   %searchResult = containerRayCast(%eyePos, %eyeEnd, %mask, 0);

   return %searchResult;
}

//-----------------------//
// Deployable Procedures //
//-----------------------//

//-------------------------------------------------
function ShapeBaseImageData::testMaxDeployed(%item, %plyr)
{
   if(%item.item $= TurretOutdoorDeployable || %item.item $= TurretIndoorDeployable)
      %itemCount = countTurretsAllowed(%item.item);
   else
      %itemCount = $TeamDeployableMax[%item.item];

   return $TeamDeployedCount[%plyr.team, %item.item] >= %itemCount;
}

//-------------------------------------------------
function ShapeBaseImageData::testNoSurfaceInRange(%item, %plyr)
{
   return ! Deployables::searchView(%plyr, $MaxDeployDistance, $TypeMasks::TerrainObjectType | $TypeMasks::InteriorObjectType);
}

//-------------------------------------------------
function ShapeBaseImageData::testSlopeTooGreat(%item)
{
   if (%item.surface)
   {          
      return getTerrainAngle(%item.surfaceNrm) > %item.maxDepSlope;
   }   
}

//-------------------------------------------------
function ShapeBaseImageData::testSelfTooClose(%item, %plyr)
{
   InitContainerRadiusSearch(%item.surfacePt, $MinDeployDistance, $TypeMasks::PlayerObjectType);

   return containerSearchNext() == %plyr; 
}

//-------------------------------------------------
function ShapeBaseImageData::testObjectTooClose(%item)
{
   InitContainerRadiusSearch( %item.surfacePt, $MinDeployDistance,
               $TypeMasks::VehicleObjectType     | $TypeMasks::MoveableObjectType   |
               $TypeMasks::StaticShapeObjectType | $TypeMasks::StaticTSObjectType   | 
               $TypeMasks::ForceFieldObjectType  | $TypeMasks::ItemObjectType       | 
               $TypeMasks::PlayerObjectType      | $TypeMasks::TurretObjectType);

   %test = containerSearchNext();
   return %test;
}


//-------------------------------------------------
function TurretOutdoorDeployableImage::testNoTerrainFound(%item)
{
   return %item.surface.getClassName() !$= TerrainBlock;
}

function ShapeBaseImageData::testNoTerrainFound(%item, %surface)
{
   //don't check this for non-Landspike turret deployables
}

//-------------------------------------------------
function TurretIndoorDeployableImage::testNoInteriorFound(%item)
{
   return %item.surface.getClassName() !$= InteriorInstance;
}

function ShapeBaseImageData::testNoInteriorFound(%item, %surface)
{
   //don't check this for non-Clasping turret deployables
}

//-------------------------------------------------
function TurretIndoorDeployableImage::testHavePurchase(%item, %xform)
{
   %footprintRadius = 0.34;
   %collMask = $TypeMasks::InteriorObjectType;
   return %item.deployed.checkDeployPurchase(%xform, %footprintRadius, %collMask);
}

function ShapeBaseImageData::testHavePurchase(%item, %xform)
{
   //don't check this for non-Clasping turret deployables
   return true;
}
                                             
//-------------------------------------------------
function ShapeBaseImageData::testInventoryTooClose(%item, %plyr)
{
   return false;
}

function InventoryDeployableImage::testInventoryTooClose(%item, %plyr)
{
   InitContainerRadiusSearch(%item.surfacePt, $InventorySpaceRadius, $TypeMasks::StaticShapeObjectType);

   // old function was only checking whether the first object found was a turret -- also wasn't checking
   // which team the object was on
   %turretInRange = false;
   while((%found = containerSearchNext()) != 0)
   {
      %foundName = %found.getDataBlock().getName();
      if( (%foundName $= DeployedStationInventory) )
         if (%found.team == %plyr.team)
         {
            %turretInRange = true;
            break;
         }
   }
   return %turretInRange;
}

function TurretIndoorDeployableImage::testTurretTooClose(%item, %plyr)
{
   InitContainerRadiusSearch(%item.surfacePt, $TurretIndoorSpaceRadius, $TypeMasks::StaticShapeObjectType);

   // old function was only checking whether the first object found was a turret -- also wasn't checking
   // which team the object was on
   %turretInRange = false;
   while((%found = containerSearchNext()) != 0)
   {
      %foundName = %found.getDataBlock().getName();
      if((%foundname $= TurretDeployedFloorIndoor) || (%foundName $= TurretDeployedWallIndoor) || (%foundName $= TurretDeployedCeilingIndoor) || (%foundName $= TurretDeployedOutdoor) )
         if (%found.team == %plyr.team)
         {
            %turretInRange = true;
            break;
         }
   }
   return %turretInRange;
}

function TurretOutdoorDeployableImage::testTurretTooClose(%item, %plyr)
{
   InitContainerRadiusSearch(%item.surfacePt, $TurretOutdoorSpaceRadius, $TypeMasks::StaticShapeObjectType);

   // old function was only checking whether the first object found was a turret -- also wasn't checking
   // which team the object was on
   %turretInRange = false;
   while((%found = containerSearchNext()) != 0)
   {
      %foundName = %found.getDataBlock().getName();
      if((%foundname $= TurretDeployedFloorIndoor) || (%foundName $= TurretDeployedWallIndoor) || (%foundName $= TurretDeployedCeilingIndoor) || (%foundName $= TurretDeployedOutdoor) )
         if (%found.team == %plyr.team)
         {
            %turretInRange = true;
            break;
         }
   }
   return %turretInRange;
}

function ShapeBaseImageData::testTurretTooClose(%item, %plyr)
{
   //don't check this for non-turret deployables
}

//-------------------------------------------------
function TurretIndoorDeployableImage::testTurretSaturation(%item)
{
   %highestDensity = 0;
   InitContainerRadiusSearch(%item.surfacePt, $TurretIndoorSphereRadius, $TypeMasks::StaticShapeObjectType);
   %found = containerSearchNext();
   while(%found)
   {
      %foundName = %found.getDataBlock().getName();
      if((%foundname $= TurretDeployedFloorIndoor) || (%foundName $= TurretDeployedWallIndoor) || (%foundName $= TurretDeployedCeilingIndoor) || (%foundName $= TurretDeployedOutdoor) )
      {
           //found one
           %numTurretsNearby++;

       %nearbyDensity = testNearbyDensity(%found, $TurretIndoorSphereRadius);
       if (%nearbyDensity > %highestDensity)
          %highestDensity = %nearbyDensity;     
      }
     %found = containerSearchNext();
   }

   if (%numTurretsNearby > %highestDensity)
      %highestDensity = %numTurretsNearby;
   return %highestDensity > $TurretIndoorMaxPerSphere;
}

function TurretOutdoorDeployableImage::testTurretSaturation(%item)
{
   %highestDensity = 0;
   InitContainerRadiusSearch(%item.surfacePt, $TurretOutdoorSphereRadius, $TypeMasks::StaticShapeObjectType);
   %found = containerSearchNext();
   while(%found)
   {
      %foundName = %found.getDataBlock().getName();
      if((%foundname $= TurretDeployedFloorIndoor) || (%foundName $= TurretDeployedWallIndoor) || (%foundName $= TurretDeployedCeilingIndoor) || (%foundName $= TurretDeployedOutdoor) )
      {
           //found one
           %numTurretsNearby++;

       %nearbyDensity = testNearbyDensity(%found, $TurretOutdoorSphereRadius);
       if (%nearbyDensity > %highestDensity)
          %highestDensity = %nearbyDensity;     
      }
     %found = containerSearchNext();
   }

   if (%numTurretsNearby > %highestDensity)
      %highestDensity = %numTurretsNearby;
   return %highestDensity > $TurretOutdoorMaxPerSphere;
}

function ShapeBaseImageData::testTurretSaturation(%item, %surfacePt)
{
   //don't check this for non-turret deployables
}

function testNearbyDensity(%item, %radius)
{
   //this checks how many turrets are in adjacent spheres in case placing a new one overloads them.
   %surfacePt = posFromTransform(%item.getTransform());
   %turretCount = 0;

   InitContainerRadiusSearch(%surfacePt, %radius, $TypeMasks::StaticShapeObjectType);
   %found = containerSearchNext();
   while(%found)
   {
      %foundName = %found.getDataBlock().getName();
      if((%foundname $= TurretDeployedFloorIndoor) || (%foundName $= TurretDeployedWallIndoor) || (%foundName $= TurretDeployedCeilingIndoor) || (%foundName $= TurretDeployedOutdoor) )
         %turretCount++;       
     %found = containerSearchNext();      
   }
   return %turretCount;
}

//-------------------------------------------------
//if this function, or any of the included tests are changed, those changes need to be reflected in function:
//AIODeployEquipment::weight(%this, %client, %level), found in aiObjectives.cs  --tinman
function ShapeBaseImageData::testInvalidDeployConditions(%item, %plyr, %slot)
{
   cancel(%plyr.deployCheckThread);
   %disqualified = $NotDeployableReason::None;  //default
   $MaxDeployDistance = %item.maxDeployDis; 
   $MinDeployDistance = %item.minDeployDis; 
   
   %surface = Deployables::searchView(%plyr,
                                      $MaxDeployDistance,
                                      ($TypeMasks::TerrainObjectType |
                                       $TypeMasks::InteriorObjectType));
   if (%surface)  
   {  
      %surfacePt  = posFromRaycast(%surface);
      %surfaceNrm = normalFromRaycast(%surface);

      // Check that point to see if anything is objstructing it...
      %eyeTrans = %plyr.getEyeTransform();
      %eyePos   = posFromTransform(%eyeTrans);

      %searchResult = containerRayCast(%eyePos, %surfacePt, -1, %plyr);
      if (!%searchResult)
      {
         %item.surface = %surface;
         %item.surfacePt = %surfacePt;
         %item.surfaceNrm = %surfaceNrm;
      }
      else
      {
         if(checkPositions(%surfacePT, posFromRaycast(%searchResult)))
         {
            %item.surface = %surface;
            %item.surfacePt = %surfacePt;
            %item.surfaceNrm = %surfaceNrm;
         }
         else
         {
            // Don't set the item
            %disqualified = $NotDeployableReason::ObjectTooClose;
         }
      }
      if(!getTerrainAngle(%surfaceNrm) && %item.flatMaxDeployDis !$= "")
      {
         $MaxDeployDistance = %item.flatMaxDeployDis; 
         $MinDeployDistance = %item.flatMinDeployDis; 
      }
   }

   if (%item.testMaxDeployed(%plyr))
   {
      %disqualified = $NotDeployableReason::MaxDeployed;
   }
   else if (%item.testNoSurfaceInRange(%plyr))
   {
      %disqualified = $NotDeployableReason::NoSurfaceFound;
   }
   else if (%item.testNoTerrainFound(%surface))
   {
      %disqualified = $NotDeployableReason::NoTerrainFound;
   }
   else if (%item.testNoInteriorFound())
   {
      %disqualified = $NotDeployableReason::NoInteriorFound;
   }
   else if (%item.testSlopeTooGreat(%surface, %surfaceNrm))
   {
      %disqualified = $NotDeployableReason::SlopeTooGreat;
   }
   else if (%item.testSelfTooClose(%plyr, %surfacePt))
   {
      %disqualified = $NotDeployableReason::SelfTooClose;
   }
   else if (%item.testObjectTooClose(%surfacePt))
   {
      %disqualified = $NotDeployableReason::ObjectTooClose;   
   }
   else if (%item.testTurretTooClose(%plyr))
   {
      %disqualified = $NotDeployableReason::TurretTooClose;
   }
   else if (%item.testInventoryTooClose(%plyr))
   {
      %disqualified = $NotDeployableReason::InventoryTooClose;
   }
   else if (%item.testTurretSaturation())
   {
      %disqualified = $NotDeployableReason::TurretSaturation;
   }
   else if (%disqualified == $NotDeployableReason::None)
   {
      // Test that there are no objstructing objects that this object
      //  will intersect with
      //
      %rot = %item.getInitialRotation(%plyr);
      if(%item.deployed.className $= "DeployedTurret")
      {
         %xform = %item.deployed.getDeployTransform(%item.surfacePt, %item.surfaceNrm);
      }
      else
      {
         %xform = %surfacePt SPC %rot;
      }
      
      if (!%item.deployed.checkDeployPos(%xform) && %item.deployed.className !$= "ForceField")
      {
         %disqualified = $NotDeployableReason::ObjectTooClose;
      }
      else if (!%item.testHavePurchase(%xform))
      {
         %disqualified = $NotDeployableReason::SurfaceTooNarrow;
      }
   }

   if (%plyr.getMountedImage($BackpackSlot) == %item)  //player still have the item?
   {
      if (%disqualified)
         activateDeploySensorRed(%plyr);
      else
         activateDeploySensorGrn(%plyr);      

      if (%plyr.client.deployPack == true)
         %item.attemptDeploy(%plyr, %slot, %disqualified);       
      else
      {
         %plyr.deployCheckThread = %item.schedule(25, "testInvalidDeployConditions", %plyr, %slot); //update checks every 50 milliseconds
      }
   }
   else
       deactivateDeploySensor(%plyr);
}

function checkPositions(%pos1, %pos2)
{
   %passed = true;
   if((mFloor(getWord(%pos1, 0)) - mFloor(getWord(%pos2,0))))
      %passed = false;   
   if((mFloor(getWord(%pos1, 1)) - mFloor(getWord(%pos2,1))))
      %passed = false;   
   if((mFloor(getWord(%pos1, 2)) - mFloor(getWord(%pos2,2))))
      %passed = false;
   return %passed;      
}

function ShapeBaseImageData::attemptDeploy(%item, %plyr, %slot, %disqualified)
{
   deactivateDeploySensor(%plyr);
   Deployables::displayErrorMsg(%item, %plyr, %slot, %disqualified);
}  

function activateDeploySensorRed(%pl)
{
   if(%pl.deploySensor !$= "red")
   {
      messageClient(%pl.client, 'msgDeploySensorRed', "");
      %pl.deploySensor = "red";
   }
}

function activateDeploySensorGrn(%pl)
{
   if(%pl.deploySensor !$= "green")
   {
      messageClient(%pl.client, 'msgDeploySensorGrn', "");
      %pl.deploySensor = "green";
   }
}  

function deactivateDeploySensor(%pl)
{
   if (%pl.deploySensor !$= "")
   {
      messageClient(%pl.client, 'msgDeploySensorOff', "");
      %pl.deploySensor = "";
   }
}
   
function Deployables::displayErrorMsg(%item, %plyr, %slot, %error)
{
   deactivateDeploySensor(%plyr);
   
   %errorSnd = '~wfx/misc/misc.error.wav';
   switch (%error)
   {
      case $NotDeployableReason::None:
         %item.onDeploy(%plyr, %slot);
         messageClient(%plyr.client, 'MsgTeamDeploySuccess', "");
         return;

      case $NotDeployableReason::NoSurfaceFound:
         %msg = '\c2Item must be placed within reach.%1';

      case $NotDeployableReason::MaxDeployed:
         %msg = '\c2Your team\'s control network has reached its capacity for this item.%1';

      case $NotDeployableReason::SlopeTooGreat:
         %msg = '\c2Surface is too steep to place this item on.%1';

      case $NotDeployableReason::SelfTooClose:
         %msg = '\c2You are too close to the surface you are trying to place the item on.%1';

      case $NotDeployableReason::ObjectTooClose:
         %msg = '\c2You cannot place this item so close to another object.%1';

      case $NotDeployableReason::NoTerrainFound:
         %msg = '\c2You must place this on outdoor terrain.%1';

      case $NotDeployableReason::NoInteriorFound:
         %msg = '\c2You must place this on a solid surface.%1';

      case $NotDeployableReason::TurretTooClose:
         %msg = '\c2Interference from a nearby turret prevents placement here.%1';

      case $NotDeployableReason::TurretSaturation:
         %msg = '\c2There are too many turrets nearby.%1';
         
      case $NotDeployableReason::SurfaceTooNarrow:
         %msg = '\c2There is not adequate surface to clamp to here.%1';

      case $NotDeployableReason::InventoryTooClose:
         %msg = '\c2Interference from a nearby inventory prevents placement here.%1';

      default:
         %msg = '\c2Deploy failed.';
   }
   messageClient(%plyr.client, 'MsgDeployFailed', %msg, %errorSnd);
}  

function ShapeBaseImageData::onActivate(%data, %obj, %slot)
{
   //Tinman - apparently, anything that uses the generic onActivate() method is a deployable.
   //repair packs, cloak packs, shield, etc...  all overload this method...
   %data.testInvalidDeployConditions(%obj, %slot);

   //whether the test passed or not, reset the image trigger (deployables don't have an on/off toggleable state)
   %obj.setImageTrigger(%slot, false);
}

function ShapeBaseImageData::onDeploy(%item, %plyr, %slot)
{
   if(%item.item $= "MotionSensorDeployable" || %item.item $= "PulseSensorDeployable")
   {
      %plyr.deploySensors--;
      %plyr.client.updateSensorPackText(%plyr.deploySensors);
      if(%plyr.deploySensors <= 0)
      {
         // take the deployable off the player's back and out of inventory
         %plyr.unmountImage(%slot);
         %plyr.decInventory(%item.item, 1);  
      }
   }
   else
   {
      // take the deployable off the player's back and out of inventory
      %plyr.unmountImage(%slot);
      %plyr.decInventory(%item.item, 1);  
   }
   
   // create the actual deployable
   %rot = %item.getInitialRotation(%plyr);
   if(%item.deployed.className $= "DeployedTurret")
      %className = "Turret";
   else
      %className = "StaticShape";

   %deplObj = new (%className)() {
      dataBlock = %item.deployed;
   };
   
   
   // set orientation
   if(%className $= "Turret")
      %deplObj.setDeployRotation(%item.surfacePt, %item.surfaceNrm);
   else
      %deplObj.setTransform(%item.surfacePt SPC %rot);

   // set the recharge rate right away
   if(%deplObj.getDatablock().rechargeRate)
      %deplObj.setRechargeRate(%deplObj.getDatablock().rechargeRate);
   
   // set team, owner, and handle
   %deplObj.team = %plyr.client.Team;
   %deplObj.owner = %plyr.client;

   // set the sensor group if it needs one
   if(%deplObj.getTarget() != -1)
      setTargetSensorGroup(%deplObj.getTarget(), %plyr.client.team);

   // place the deployable in the MissionCleanup/Deployables group (AI reasons)
   addToDeployGroup(%deplObj);

   //let the AI know as well...
   AIDeployObject(%plyr.client, %deplObj);

   // play the deploy sound
   serverPlay3D(%item.deploySound, %deplObj.getTransform());

   // increment the team count for this deployed object

   $TeamDeployedCount[%plyr.team, %item.item]++;
   %deplObj.deploy();
   return %deplObj;  
}

function ShapeBaseImageData::getInitialRotation(%item, %plyr)
{
   return rotFromTransform(%plyr.getTransform());
}

function MotionSensorDeployableImage::getInitialRotation(%item, %plyr)
{
   %rotAxis = vectorNormalize(vectorCross(%item.surfaceNrm, "0 0 1"));
   if (getWord(%item.surfaceNrm, 2) == 1 || getWord(%item.surfaceNrm, 2) == -1)
      %rotAxis = vectorNormalize(vectorCross(%item.surfaceNrm, "0 1 0"));     
   return %rotAxis SPC mACos(vectorDot(%item.surfaceNrm, "0 0 1"));
}

function MotionSensorDeployable::onPickup(%this, %pack, %player, %amount)
{
   // %this = Sensor pack datablock
   // %pack = Sensor pack object number
   // %player = player
   // %amount = amount picked up (1)

   if(%pack.sensors $= "")
   {
      // assume that this is a pack that has been placed in a mission
      // this case was handled in ::onInventory below (max sensors);
   }
   else
   {
      // find out how many sensor were in the pack
      %player.deploySensors = %pack.sensors;
      %player.client.updateSensorPackText(%player.deploySensors);
   }
}

function MotionSensorDeployable::onThrow(%this,%pack,%player)
{
   // %this = Sensor pack datablock
   // %pack = Sensor pack object number
   // %player = player

   %player.throwSensorPack = 1;
   %pack.sensors = %player.deploySensors;
   %player.deploySensors = 0;
   %player.client.updateSensorPackText(%player.deploySensors);
   // do the normal ItemData::onThrow stuff -- sound and schedule deletion
   serverPlay3D(ItemThrowSound, %player.getTransform());
   %pack.schedulePop();
}

function MotionSensorDeployable::onInventory(%this,%player,%value)
{
   // %this = Sensor pack datablock
   // %player = player
   // %value = 1 if gaining a pack, 0 if losing a pack

   if(%player.getClassName() $= "Player")
   {
      if(%value)
      {
         // player picked up or bought a motion sensor pack
         %player.deploySensors = %this.maxSensors;
         %player.client.updateSensorPackText(%player.deploySensors);
      }
      else
      {
         // player dropped or sold a motion sensor pack
         if(%player.throwSensorPack)
         {
            // player threw the pack
            %player.throwSensorPack = 0;
            // everything handled in ::onThrow above
         }
         else
         {
            //the pack was sold at an inventory station, or unmounted because the player
            // used all the sensors
            %player.deploySensors = 0;
            %player.client.updateSensorPackText(%player.deploySensors);
         }
      }
   }
   Pack::onInventory(%this,%player,%value);
}

function PulseSensorDeployable::onPickup(%this, %pack, %player, %amount)
{
   // %this = Sensor pack datablock
   // %pack = Sensor pack object number
   // %player = player
   // %amount = amount picked up (1)

   if(%pack.sensors $= "")
   {
      // assume that this is a pack that has been placed in a mission
      // this case was handled in ::onInventory below (max sensors);
   }
   else
   {
      // find out how many sensor were in the pack
      %player.deploySensors = %pack.sensors;
      %player.client.updateSensorPackText(%player.deploySensors);
   }
}

function PulseSensorDeployable::onThrow(%this,%pack,%player)
{
   // %this = Sensor pack datablock
   // %pack = Sensor pack object number
   // %player = player

   %player.throwSensorPack = 1;
   %pack.sensors = %player.deploySensors;
   %player.deploySensors = 0;
   %player.client.updateSensorPackText(%player.deploySensors);
   // do the normal ItemData::onThrow stuff -- sound and schedule deletion
   serverPlay3D(ItemThrowSound, %player.getTransform());
   %pack.schedulePop();
}

function PulseSensorDeployable::onInventory(%this,%player,%value)
{
   // %this = Sensor pack datablock
   // %player = player
   // %value = 1 if gaining a pack, 0 if losing a pack

   if(%player.getClassName() $= "Player")
   {
      if(%value)
      {
         // player picked up or bought a motion sensor pack
         %player.deploySensors = %this.maxSensors;
         %player.client.updateSensorPackText(%player.deploySensors);
      }
      else
      {
         // player dropped or sold a motion sensor pack
         if(%player.throwSensorPack)
         {
            // player threw the pack
            %player.throwSensorPack = 0;
            // everything handled in ::onThrow above
         }
         else
         {
            //the pack was sold at an inventory station, or unmounted because the player
            // used all the sensors
            %player.deploySensors = 0;
            %player.client.updateSensorPackText(%player.deploySensors);
         }
      }
   }
   Pack::onInventory(%this,%player,%value);
}

function TurretIndoorDeployableImage::getInitialRotation(%item, %plyr)
{
   %surfaceAngle = getTerrainAngle(%item.surfaceNrm);
   if(%surfaceAngle > 155)
      %item.deployed = TurretDeployedCeilingIndoor;
   else if(%surfaceAngle > 45)
      %item.deployed = TurretDeployedWallIndoor;
   else
      %item.deployed = TurretDeployedFloorIndoor;
}  

function TurretIndoorDeployable::onPickup(%this, %obj, %shape, %amount)
{
   // created to prevent console errors
}

function TurretOutdoorDeployable::onPickup(%this, %obj, %shape, %amount)
{
   // created to prevent console errors
}

function InventoryDeployable::onPickup(%this, %obj, %shape, %amount)
{
   // created to prevent console errors
}

// ---------------------------------------------------------------------------------------
// deployed station functions
function DeployedStationInventory::onEndSequence(%data, %obj, %thread)
{
   Parent::onEndSequence(%data, %obj, %thread);
   if(%thread == $DeployThread)
   {
      %trigger = new Trigger()
      {
         dataBlock = stationTrigger;
         polyhedron = "-0.125 0.0 0.1 0.25 0.0 0.0 0.0 -0.7 0.0 0.0 0.0 1.0";
      };             
      MissionCleanup.add(%trigger);
   
      %trans = %obj.getTransform();
      %vSPos = getWords(%trans,0,2);
      %vRot =  getWords(%trans,3,5);
      %vAngle = getWord(%trans,6);
      %matrix = VectorOrthoBasis(%vRot @ " " @ %vAngle + 0.0);
      %yRot = getWords(%matrix, 3, 5);
      %pos = vectorAdd(%vSPos, vectorScale(%yRot, -0.1));
   
      %trigger.setTransform(%pos @ " " @ %vRot @ " " @ %vAngle);

      // associate the trigger with the station
      %trigger.station = %obj;
      %trigger.mainObj = %obj;
      %trigger.disableObj = %obj;
      %obj.trigger = %trigger;
   }
}

//--------------------------------------------------------------------------
//DeployedMotionSensor:
//--------------------------------------------------------------------------

function DeployedMotionSensor::onDestroyed(%this, %obj, %prevState)
{
   //%obj.hide(true);
   Parent::onDestroyed(%this, %obj, %prevState);
   $TeamDeployedCount[%obj.team, MotionSensorDeployable]--;
   %obj.schedule(500, "delete");
}

//--------------------------------------------------------------------------
//DeployedPulseSensor:
//--------------------------------------------------------------------------
function PulseSensorDeployableImage::onActivate(%data, %obj, %slot)
{
   Parent::onActivate( %data, %obj, %slot );
   //%data.testInvalidDeployConditions(%obj, %slot);
}

function DeployedPulseSensor::onDestroyed(%this, %obj, %prevState)
{
   Parent::onDestroyed(%this, %obj, %prevState);
   $TeamDeployedCount[%obj.team, PulseSensorDeployable]--;
   %obj.schedule(300, "delete");
}

// ---------------------------------------------------------------------------------------
// deployed turret functions

function DeployedTurret::onAdd(%data, %obj)
{
   Parent::onAdd(%data, %obj);
   // auto-mount the barrel
   %obj.mountImage(%data.barrel, 0, false);
}

function DeployedTurret::onDestroyed(%this, %obj, %prevState)
{
   Parent::onDestroyed(%this, %obj, %prevState);
   %turType = %this.getName();
   // either it'll be an outdoor turret, or one of the three types of indoor turret
   // (floor, ceiling, wall)
   if(%turType $= "TurretDeployedOutdoor")
      %turType = "TurretOutdoorDeployable";
   else
      %turType = "TurretIndoorDeployable";

   // decrement team count
   $TeamDeployedCount[%obj.team, %turType]--;

   %obj.schedule(700, "delete");
}

function countTurretsAllowed(%type)
{
   for(%j = 1; %j < Game.numTeams; %j++)
      %teamPlayerCount[%j] = 0;
   %numClients = ClientGroup.getCount();
   for(%i = 0; %i < %numClients; %i++)
   {
      %cl = ClientGroup.getObject(%i);
      if(%cl.team > 0)
         %teamPlayerCount[%cl.team]++;
   }
   // the bigger team determines the number of turrets allowed
   %maxPlayers = %teamPlayerCount[1] > %teamPlayerCount[2] ? %teamPlayerCount[1] : %teamPlayerCount[2];
   // each team can have 1 turret of each type (indoor/outdoor) for every 2 players
   // minimum and maximums are defined in deployables.cs
   %teamTurretMax = mFloor(%maxPlayers / 2);
   if(%teamTurretMax < $TeamDeployableMin[%type])
      %teamTurretMax = $TeamDeployableMin[%type];
   else if(%teamTurretMax > $TeamDeployableMax[%type])
      %teamTurretMax = $TeamDeployableMax[%type];
   
   return %teamTurretMax;
}

//============================================= >Modification Zone<
//====================================== Deployable Turret Base
//$TeamDeployableMax[TurretBasePack] = 5;

datablock TurretData(FreeBaseTurret) : TurretDamageProfile
{
   className      = TurretBase;
   catagory       = "Turrets";
   shapeFile      = "turret_base_large.dts";
   preload        = true;

   mass           = 1.0;  // Not really relevant

   maxDamage      = 2.25;
   destroyedLevel = 2.25;
   disabledLevel  = 1.35;
   explosion      = TurretExplosion;
	expDmgRadius = 15.0;
	expDamage = 0.7;
	expImpulse = 2000.0;
   repairRate     = 0;
   emap = true;

   thetaMin = 15;
   thetaMax = 140;
   deployedObject = true;

   isShielded           = true;
   energyPerDamagePoint = 50;
   maxEnergy = 150;
   rechargeRate = 0.31;
   humSound = SensorHumSound;
   pausePowerThread = true;

   canControl = true;
   cmdCategory = "Tactical";
   cmdIcon = CMDTurretIcon;
   cmdMiniIconName = "commander/MiniIcons/com_turretbase_grey";
   targetNameTag = 'Deployed Base';
   targetTypeTag = 'Turret';
   sensorData = TurretBaseSensorObj;
   sensorRadius = TurretBaseSensorObj.detectRadius;
   sensorColor = "0 212 45";

   firstPersonOnly = true;

   debrisShapeName = "debris_generic.dts";
   debris = TurretDebris;
};


datablock ShapeBaseImageData(TurretBaseImage)
{
   mass = 20;

   shapeFile = "pack_deploy_turreti.dts";
   item = TurretBasePack;
   mountPoint = 1;
   offset = "0 0 0";
   deployed = FreeBaseTurret;

   stateName[0] = "Idle";
   stateTransitionOnTriggerDown[0] = "Activate";

   stateName[1] = "Activate";
   stateScript[1] = "onActivate";
   stateTransitionOnTriggerUp[1] = "Idle";

   isLarge = true;
   emap = true;

   maxDepSlope = 60;
   deploySound = TurretDeploySound;
   
   minDeployDis                       =  0.5;
   maxDeployDis                       =  5.0;  //meters from body
};

datablock ItemData(TurretBasePack)
{
   className = Pack;
   catagory = "Deployables";
   shapeFile = "pack_deploy_turreti.dts";
   mass = 3.0;
   elasticity = 0.2;
   friction = 0.6;
   pickupRadius = 1;
   rotate = false;
   image = "TurretBaseImage";
   pickUpName = "a deployable turret base";
   heatSignature = 0;

   emap = true;
};

function TurretBasePack::onPickup(%this, %obj, %shape, %amount)
{
   // created to prevent console errors
}

function TurretBaseImage::onDeploy(%item, %plyr, %slot)
{
     %plyr.unmountImage(%slot);
     %plyr.decInventory(%item.item, 1);

     %rot = %item.getInitialRotation(%plyr);

     %turret =	new Turret()
     {
		dataBlock = "FreeBaseTurret";
		initialBarrel = "PlasmaBarrelLarge";
	};

     MissionCleanup.add(%turret);

     %turret.setTransform(%item.surfacePt SPC %rot);
     %turret.setSelfPowered();          // unlock

     if(%turret.getDatablock().rechargeRate)
           %turret.setRechargeRate(%turret.getDatablock().rechargeRate);

     %turret.team = %plyr.client.Team;
     %turret.owner = %plyr.client;

     if(%turret.getTarget() != -1)
           setTargetSensorGroup(%turret.getTarget(), %plyr.client.team);

     addToDeployGroup(%turret);
     AIDeployObject(%plyr.client, %turret);
     serverPlay3D(%item.deploySound, %turret.getTransform());
     $TeamDeployedCount[%plyr.team, "TurretBasePack"]++;     // just fine
     %turret.deploy();
     return %turret;
}

function FreeBaseTurret::onDestroyed(%this, %obj, %prevState)
{
   Parent::onDestroyed(%this, %obj, %prevState);
   $TeamDeployedCount[%obj.team, TurretBasePack]--;
   %obj.schedule(500, "delete");
}

//====================================== Deployable Teleport Pads
//$TeamDeployableMax[TelePack] = 2;

//------------------------------------------------------------------------------
// Teleportpad
//------------------------------------------------------------------------------

datablock AudioProfile(TelepoadHum)
{
   fileName = "fx/powered/turret_heavy_idle.wav";
   description = CloseLooping3d;
   preload = true;
};

datablock ShapeBaseImageData(TelePadDeployableImage)
{
mass = 15;
emap = true;

shapeFile = "stackable1s.dts";
item = TelePack;
mountPoint = 1;
offset = "0 -0.2 0";

deployed = TelePadDeployedBase;
heatSignature = 0.5;

stateName[0] = "Idle";
stateTransitionOnTriggerDown[0] = "Activate";

stateName[1] = "Activate";
stateScript[1] = "onActivate";
stateTransitionOnTriggerUp[1] = "Idle";

isLarge = true;
maxDepSlope = 30;
deploySound = StationDeploySound;
minDeployDis = 0.5;
maxDeployDis = 5.0;
};

datablock ItemData(TelePack)
{
className = Pack;
catagory = "Deployables";
shapeFile = "stackable1s.dts";
mass = 3.0;
elasticity = 0.2;
friction = 0.6;
pickupRadius = 1;
rotate = false;
image = "TelePadDeployableImage";
pickUpName = "a teleport pad";
heatSignature = 0;

computeCRC = true;
emap = true;

};

datablock SensorData(TelePadBaseSensorObj)
{
detects = true;
detectsUsingLOS = true;
detectsPassiveJammed = false;
detectsActiveJammed = false;
detectsCloaked = false;
detectionPings = true;
detectRadius = 10;
};


datablock StaticShapeData(TelePadDeployedBase) : StaticShapeDamageProfile
{
className = "Station";
catagory = "Deployables";
shapefile = "NexusBase.dts";

rechargeRate = 0.31;

needsNoPower = true;

dynamicType = $TypeMasks::StationObjectType;
mass = 5.0;
maxDamage = 2.00;
destroyedLevel = 2.00;
disabledLevel = 1.35;
repairRate = 0;
explosion = DeployablesExplosion;
expDmgRadius = 18.0;
expDamage = 0.8;
expImpulse = 2000.0;

deployedObject = true;

energyPerDamagePoint = 50;
maxEnergy = 150;

humSound = TelepoadHum;
heatSignature = 0;
pausePowerThread = true;

debrisShapeName = "debris_generic.dts";
debris = DeployableDebris;

cmdIcon = CMDSwitchIcon;
cmdCategory = "DSupport";
cmdMiniIconName = "commander/MiniIcons/com_switch_grey";
targetNameTag = 'Teleport';
targetTypeTag = 'Pad';

sensorData = TelePadBaseSensorObj;
sensorRadius = TelePadBaseSensorObj.detectRadius;
sensorColor = "0 212 45";

firstPersonOnly = true;

//lightOnlyStatic = true;
lightType = "PulsingLight";
lightColor = "8.0 0.0 0.0 1.0";
lightTime = 10000;
lightRadius = 20;

deployedFrom = TelePack;

};

datablock StaticShapeData(TelepadCap)
{
className = "Teleporter";
catagory = "DSupport";
shapefile = "Nexuscap.dts";
collideable = 1;
needsNoPower = true;
emap="true";
sensorData = TelePadBaseSensorObj;
sensorRadius = TelePadBaseSensorObj.detectRadius;
sensorColor = "0 212 45";

cmdCategory = "DSupport";
targetNameTag = 'Teleport';
targetTypeTag = 'Pad';

//lightOnlyStatic = true;
lightType = "PulsingLight";
lightColor = "8.0 0.0 0.0 1.0";
lightTime = 10000;
lightRadius = 20;
};

// functions
function TelePadDeployedBase::onadd(%this, %obj)
{
Parent::onAdd(%this, %obj);

%pos = %obj.getTransform();
%pos = getWords(%pos, 0, 1) @ " " @ getWord(%pos, 2) + 5;

%obj.playThread(1, "transition");
%obj.setThreadDir(1, true);

}

function TelePadDeployedBase::onDestroyed(%this, %obj, %prevState)
{
echo("pad " @ %obj @ " destroyed!");
Parent::onDestroyed(%this, %obj, %prevState);
$TeamDeployedCount[%obj.team, TelePack]--;

if($TeamDeployedCount[%obj.team, TelePack] > 0) // this wasnt the last
{
if($firstPad[%obj.team] == %obj) // the first was destroyed
{
echo("first pad destroyed");
$firstPad[%obj.team] = %obj.nextPad; // make the second one the first
echo("first pad (" @ %obj @ ") destroyed, new first :" @ $firstPad[%obj.team]);
$firstPad[%obj.team].prevPad = -1;
}
else
{
%obj.prevPad.nextPad = %obj.nextPad;
%obj.nextPad.prevPad = %obj.prevPad;
}

//blow up another one, maybe
%rnd = mFloor(getRandom() * 10);
echo("rnd " @ mFloor(%rnd));
if(%rnd == 5) // one in ten chance
{
echo("another pad blows up");
%obj.nextPad.setDamageLevel(2.01);
}
}
else // last one
$firstPad[%obj.team] = ""; // remove it

//blow up

%obj.cap.schedule(10, "delete");
%obj.schedule(15, "delete");
}

function TelePadDeployedBase::onCollision(%data, %obj, %col)
{
if(%col.justTeleported)
return;

%teleteam = %obj.team;

if(%obj.Hacked) // if it is hacked, work some mojo
%teleteam = %obj.OldTeam;

%pads = $TeamDeployedCount[%teleteam, TelePack];
//verify pd.team is team associated and is on player's team
if((%obj.team != %col.client.team) && (%obj.team != 0))
{
%obj.playAudio(0, TelePadAccessDeniedSound);
messageClient(%col.client, 'msgTelepadDenied', '\c2Access Denied -- Wrong team.');
%col.justTeleported = true;
schedule(2000, %col, "unteleport", %col);
return;
}
if(%pads < 2)
{
%obj.playAudio(0, TelePadAccessDeniedSound);
messageClient(%col.client, 'msgTelepadDenied', '\c2No other pads to teleport to.');
%col.justTeleported = true;
schedule(2000, %col, "unteleport", %col);
return;
}
if(%obj.teleCharging)
{
%obj.playAudio(0, TelePadAccessDeniedSound);
messageClient(%col.client, 'msgTelepadDenied', '\c2Teleport pad is recharging.');
%col.justTeleported = true;
schedule(2000, %col, "unteleport", %col);
return;
}

%rnd = getRandom();

if(%pads > 2)
%padloop = (mFloor(%rnd * (%pads - 1)) + 1);
else
%padloop = 1;

%destPad = %obj.nextPad;

echo("teleporting player " @ %col @ " from pad " @ %obj @ " to pad " @ %destPad);

//%col.startFade( 0, 0, true );

%col.justTeleported = true;
%obj.playAudio(0, IdleSound);

%col.teleportStartFX();
%obj.teleportpadFX();
%col.setWhiteout(1); // a white flash
%col.setTransform(setWord(%col.getPosition(), 2, 800) SPC "0 0 1 0"); //huck em into the sky
messageClient(%col.client, 'msgTelepadDenied', "~wfx/powered/turret_heavy_activate.wav");
schedule(3000, %col, "teleport", %col, %destPad, %obj); // shedule their teleportation

schedule(10000, %destPad, "tp_fadein", %destPad);
schedule(10000, %obj, "tp_fadein", %obj);
//schedule(1000, %col, "pl_fadein", %col);

%obj.setEnergyLevel(0);
%obj.teleCharging = true;
}

function pl_fadein(%obj)
{
%obj.startFade(50, 0, false);
}

function tp_fadein(%obj)
{
%obj.playAudio(0, TelePadBeamSound);
%obj.teleCharging = false;
}

function unteleport(%pl)
{
%pl.justTeleported = false;
}

function teleport(%pl, %destPad, %src)
{
%pl.setVelocity("0 0 0"); //slow me down, ive been falling :)
if(!isObject(%destPad)) // lost the destination
%pl.setTransform(%src.getPosition() SPC "0 0 1 0");
else
{
%pl.setTransform(vectorAdd(%destPad.getPosition(), "0 0 2") SPC "0 0 1 0");
%pl.teleportEndFX();
%destPad.teleportpadFX();
%destPad.playAudio(0, IdleSound);
%destPad.teleCharging = true;
%destPad.setEnergyLevel(0);
}
schedule(1000, %pl, "unteleport", %pl);
}

//function TelePadBeam::onCollision(%data, %obj, %col)
//{
//echo("beam collision!!!!!");
//}TelepadCap

datablock AudioProfile(TelePadAccessDeniedSound)
{
filename = "fx/weapons/ELF_underwater.wav";
description = AudioClosest3d;
preload = true;
};

datablock AudioProfile(TelePadBeamSound)
{
filename = "fx/powered/inv_pad_appear.wav";
description = AudioClosest3d;
preload = true;
};


function TelePack::onPickup(%this, %obj, %shape, %amount)
{
// created to prevent console errors
}

function TelePadDeployableImage::onDeploy(%item, %plyr, %slot)
{
%deplObj = Parent::onDeploy(%item, %plyr, %slot);

//%deplObj.playThread(1, "transition");
//%deplObj.setThreadDir(1, true);
echo("base deployed!!");

// put the cap on...  The_Force
%spot = %deplObj.getPosition();
%pos = VectorAdd(%spot, "0 0 4");

%deplObj.cap = new (StaticShape)()
{
dataBlock = TelepadCap;
position = %pos;
scale = "1 1 1"; //x z y
};
%deplObj.cap.playThread(1, "transition");
%deplObj.cap.setThreadDir(1, true);
echo("adding cap!!");

%padcnt = $TeamDeployedCount[%plyr.team, %item.item];

if(%padcnt == 1)
{
//first pad
echo("first pad : " @ %deplObj);
$firstPad[%plyr.team] = %deplObj;
%deplObj.nextPad = %deplObj;
%deplObj.prevPad = -1;
}
else
{
%lastPad = $firstPad[%plyr.team];

%txt = "pad list ";
%txta = "pad list ";
%txtb = "pad list ";

for(%i = 1; %i < (%padcnt -1); %i++) // move to the last pad so we can add the next one
%lastPad = %lastPad.nextPad;

%lastPad.nextPad = %deplObj;
%deplObj.prevPad = %lastPad;
%deplObj.nextPad = $firstPad[%plyr.team];

%a = $firstPad[%plyr.team];
echo("lastPad " @ %lastPad);
echo("firstPad " @ %a);

for(%i = 1; %i <= %padcnt; %i++)
{
%txt = %txt @ "("@%i@") t:" @ %a @ " -> ";
%txta = %txta @ "("@%i@") p:" @ %a.prevPad @ " -> ";
%txtb = %txtb @ "("@%i@") n:" @ %a.nextPad @ " -> ";
%a = %a.nextPad;
}
}
return %deplObj;
}

//code to make the tele pads link
function Teleport::onDeploy()
{
   addToTeleportGroup(%deplObj, %team);
}

function addToTeleportGroup(%object, %team)
{
   // Create a group to hold the teleporters
   %teleportGroup = nameToID("MissionCleanup/Deployables/teleports" @ %team);
   if(%teleportGroup <= 0) {
      %teleportGroup = new SimGroup("Deployables/teleports" @ %team);
      MissionCleanup.add(%teleportGroup);
   }
   %teleportGroup.add(%object);
}

function Teleporter::onCollision(%data, %obj, %col)
{
   %teleportGroup = nameToID("MissionCleanup/Deployables/teleports" @ %team);
   for(%i = 0; %i < %teleportGroup.getCount(); %i ++)
   {
      %tele = %teleportGroup.getObject(%i);
      if(%tele.getId() > %obj.getId())
      {
         // Teleport to obj
      }
      else
      {
         // some error
      }
   }
}


//====================================== Deployable Drone Bike
datablock ShapeBaseImageData(WildcatPImage)
{
   mass = 10;
   emap = true;

   shapeFile = "pack_deploy_inventory.dts";
   item = WildcatPack;
   mountPoint = 1;
   offset = "0 0 0";

   stateName[0] = "Idle";
   stateTransitionOnTriggerDown[0] = "Activate";

   stateName[1] = "Activate";
   stateScript[1] = "onActivate";
   stateTransitionOnTriggerUp[1] = "Idle";

   maxDepSlope = 45;
   deploySound = StationDeploySound;

   minDeployDis                       =  0.5;
   maxDeployDis                       =  5.0;  //meters from body
};

datablock ItemData(WildcatPack)
{
   className = Pack;
   catagory = "Deployables";
   shapeFile = "pack_deploy_inventory.dts";
   mass = 3.0;
   elasticity = 0.2;
   friction = 0.6;
   pickupRadius = 1;
   rotate = false;
   image = "WildcatPImage";
   pickUpName = "a deployable drone bike";
   heatSignature = 0;

   emap = true;
};

//$TeamDeployableMax[WildcatPack] = 15;

function WildcatPImage::onDeploy(%item, %plyr, %slot)
{
     %plyr.unmountImage(%slot);
     %plyr.decInventory(%item.item, 1);
     %rot = %item.getInitialRotation(%plyr);

      %vehicle = new FlyingVehicle()
      {
         dataBlock  = "DroneBike";
         respawn    = "0";
         teamBought = %plyr.client.Team;
         team = %plyr.client.Team;
      };

      %px = getWord(%item.surfacePt, 0);
      %py = getWord(%item.surfacePt, 1);
      %pz = getWord(%item.surfacePt, 2) + 2;
      %pos = %px@" "@%py@" "@%pz;


      %vehicle.setTransform(%pos SPC %rot);
      %plyr.setTransform(%vehicle.getTransform());
      %data = %vehicle.getDatablock();

   if((%data.sensorData !$= "") && (%vehicle.getTarget() != -1))
      setTargetSensorData(%vehicle.getTarget(), %data.sensorData);
   %vehicle.setRechargeRate(%data.rechargeRate);
   %vehicle.setEnergyLevel(%data.MaxEnergy);

   if(%vehicle.mountable || %vehicle.mountable $= "")
      %data.isMountable(%vehicle, true);
   else
      %data.isMountable(%vehicle, false);

   %vehicle.setSelfPowered();

     %vehicle.team = %plyr.client.Team;
     %vehicle.owner = %plyr.client;
     
     addToDeployGroup(%vehicle);
     AIDeployObject(%plyr.client, %vehicle);
     serverPlay3D(%item.deploySound, %vehicle.getTransform());
//     $TeamDeployedCount[%plyr.team, "WildcatPack"]++;    // just fine
}

//====================================== Deployable Inventory Station
//$TeamDeployableMax[DeployableInvHumanPack] = 3;

datablock ShapeBaseImageData(DeployableInvHumanImage)
{
   mass = 10;

   shapeFile = "pack_deploy_inventory.dts";
   item = DeployableInvHumanPack;
   mountPoint = 1;
   offset = "0 0 0";
   deployed = StationInventory;

   stateName[0] = "Idle";
   stateTransitionOnTriggerDown[0] = "Activate";

   stateName[1] = "Activate";
   stateScript[1] = "onActivate";
   stateTransitionOnTriggerUp[1] = "Idle";

   isLarge = true;
   emap = true;

   maxDepSlope = 60;
   deploySound = TurretDeploySound;

   minDeployDis                       =  0.5;
   maxDeployDis                       =  5.0;  //meters from body
};

datablock ItemData(DeployableInvHumanPack)
{
   className = Pack;
   catagory = "Deployables";
   shapeFile = "pack_deploy_inventory.dts";
   mass = 3.0;
   elasticity = 0.2;
   friction = 0.6;
   pickupRadius = 1;
   rotate = false;
   image = "DeployableInvHumanImage";
   pickUpName = "a deployable inventory station";
   heatSignature = 0;

   emap = true;
};

function DeployableInvHumanPack::onPickup(%this, %obj, %shape, %amount)
{
   // created to prevent console errors
}

function DeployableInvHumanImage::onDeploy(%item, %plyr, %slot)
{
     %plyr.unmountImage(%slot);
     %plyr.decInventory(%item.item, 1);

     %rot = %item.getInitialRotation(%plyr);

     %deplObj = new StaticShape()
     {
      dataBlock = %item.deployed;
      team = %plyr.client.team;
     };

     %deplObj.setSelfPowered();
     %deplObj.setTransform(%item.surfacePt SPC %rot);
     %deplObj.fake = true;

   %deplObj.setRechargeRate(%deplObj.getDatablock().rechargeRate);     // ripped from station.cs
   %trigger = new Trigger()
   {
      dataBlock = stationTrigger;
      polyhedron = "-0.75 0.75 0.1 1.5 0.0 0.0 0.0 -1.5 0.0 0.0 0.0 2.3";
   };
   MissionCleanup.add(%deplObj);
   %trigger.setTransform(%deplObj.getTransform());

   %trigger.station = %deplObj;
   %trigger.mainObj = %deplObj;
   %trigger.disableObj = %deplObj;
   %deplObj.trigger = %trigger;

     %deplObj.team = %plyr.client.Team;
     %deplObj.owner = %plyr.client;

     if(%deplObj.getTarget() != -1)
           setTargetSensorGroup(%deplObj.getTarget(), %plyr.client.team);

     addToDeployGroup(%deplObj);
     AIDeployObject(%plyr.client, %deplObj);
     serverPlay3D(%item.deploySound, %deplObj.getTransform());
     $TeamDeployedCount[%plyr.team, "DeployableInvHumanPack"]++;     // just fine
     %deplObj.deploy();
     if(%deplObj.getTarget() != -1)
           setTargetSensorGroup(%deplObj.getTarget(), %plyr.client.team);
     MissionCleanup.add(%deplObj);
     return %deplObj;
}

function StationInventory::onDestroyed(%this, %obj, %prevState)
{
   if(%obj.fake)
   {
        Parent::onDestroyed(%this, %obj, %prevState);
        %obj.trigger.delete();
        $TeamDeployedCount[%obj.team, "DeployableInvHumanPack"]--;
        %obj.schedule(750, "delete");
   }
   else
        Parent::onDestroyed(%this, %obj, %prevState);
}

//====================================== Deployable Forcefield (BadShot)

//***************************************************************************
//  New advanced forcfield, can be damaged if shot at the Field..
//***************************************************************************

datablock StaticShapeData(DeployedForceField) : StaticShapeDamageProfile
{
   className = ForceField;
   shapeFile = "turret_muzzlepoint.dts";
   maxDamage = 7.0;
   destroyedLevel = 7.0;
   disabledLevel = 5.5;
   dynamicType = $TypeMasks::StaticShapeObjectType;
   deployedObject = true;
   cmdCategory = "DSupport";
   cmdIcon = CMDSensorIcon;
   cmdMiniIconName = "commander/MiniIcons/com_deploymotionsensor";
   targetNameTag = 'Force Field>';
   targetTypeTag = 'Code by: BadShot';
   deployAmbientThread = true;
   heatSignature = 0;
};

/////////////// ForceField NoPass

datablock StaticShapeData(DeployedForceFieldNoPass) : StaticShapeDamageProfile
{
   className = ForceField;
   shapeFile = "turret_muzzlepoint.dts";
   maxDamage = 10.0;
   destroyedLevel = 10.0;
   disabledLevel = 9.5;
   dynamicType = $TypeMasks::StaticShapeObjectType;
   deployedObject = true;
   cmdCategory = "DSupport";
   cmdIcon = CMDSensorIcon;
   cmdMiniIconName = "commander/MiniIcons/com_deploymotionsensor";
   targetNameTag = 'Force Field No Pass>';
   targetTypeTag = 'Code by: BadShot';
   deployAmbientThread = true;
   heatSignature = 0;
};

//////////////////////   ForceField

datablock ForceFieldBareData(DeployedForceField2) : StaticShapeDamageProfile
{
   fadeMS           = 800;
   baseTranslucency = 0.14;
   powerOffTranslucency = 0.0;
   teamPermiable    = true;
   otherPermiable   = false;

   color            = "0.28 0.89 0.31";
   powerOffColor    = "0.0 0.0 0.0";

   targetTypeTag    = 'ForceField';

   texture[0] = "skins/forcef1";
   texture[1] = "skins/forcef2";
   texture[2] = "skins/forcef3";
   texture[3] = "skins/forcef4";
   texture[4] = "skins/forcef5";

   framesPerSec = 10;
   numFrames = 5;
   scrollSpeed = 15;
   umapping = 1.0;
   vmapping = 0.15;

   deployedFrom = ForceFieldDeployable;
};

//////////////////////   ForceField No pass

datablock ForceFieldBareData(DeployedForceField3) : StaticShapeDamageProfile
{

   fadeMS           = 800;
   baseTranslucency = 0.14;
   powerOffTranslucency = 0.0;
   teamPermiable    = false;
   otherPermiable   = false;

   //color            = "0.28 0.89 0.31";
   color            = "1.0 0.0 0.0 1.0";
   powerOffColor    = "0.0 0.0 0.0";

   targetTypeTag    = 'ForceField';

   texture[0] = "skins/forcef1";
   texture[1] = "skins/forcef2";
   texture[2] = "skins/forcef3";
   texture[3] = "skins/forcef4";
   texture[4] = "skins/forcef5";

   framesPerSec = 10;
   numFrames = 5;
   scrollSpeed = 15;
   umapping = 1.0;
   vmapping = 0.15;

   deployedFrom = ForceFieldNoPassDeployable;

};

/////////  ForceField

datablock ShapeBaseImageData(ForceFieldDeployableImage)
{
   mass = 20;
   emap = true;
   shapeFile = "Stackable1s.dts";
   item = ForceFieldDeployable;
   mountPoint = 1;
   offset = "0 0 0";
   deployed = DeployedForceField;
   heatSignature = 0;

   stateName[0] = "Idle";
   stateTransitionOnTriggerDown[0] = "Activate";

   stateName[1] = "Activate";
   stateScript[1] = "onActivate";
   stateTransitionOnTriggerUp[1] = "Idle";

   isLarge = true;
   maxDepSlope = 360; // 30
   deploySound = ItemPickupSound;

   minDeployDis = 0.5;
   maxDeployDis = 5.0;
};

//////////////////////   ForceField No pass

datablock ShapeBaseImageData(ForceFieldNoPassDeployableImage)
{
   mass = 20;
   emap = true;
   shapeFile = "Stackable1s.dts";
   item = ForceFieldNoPassDeployable;
   mountPoint = 1;
   offset = "0 0 0";
   deployed = DeployedForceFieldNoPass;
   heatSignature = 0;

   stateName[0] = "Idle";
   stateTransitionOnTriggerDown[0] = "Activate";

   stateName[1] = "Activate";
   stateScript[1] = "onActivate";
   stateTransitionOnTriggerUp[1] = "Idle";

   isLarge = true;
   maxDepSlope = 360; // 30
   deploySound = ItemPickupSound;

   minDeployDis = 0.5;
   maxDeployDis = 5.0;
};

//////////////////////   ForceField

datablock ItemData(ForceFieldDeployable)
{
   className = Pack;
   catagory = "Deployables";
   shapeFile = "Stackable1s.dts";
   mass = 5.0;
   elasticity = 0.2;
   friction = 0.6;
   pickupRadius = 1;
   rotate = true;
   image = "ForceFieldDeployableImage";
   pickUpName = "a force field";
   heatSignature = 0;
   emap = true;
};

//////////////////////   ForceField No pass

datablock ItemData(ForceFieldNoPassDeployable)
{
   className = Pack;
   catagory = "Deployables";
   shapeFile = "Stackable1s.dts";
   mass = 5.0;
   elasticity = 0.2;
   friction = 0.6;
   pickupRadius = 1;
   rotate = true;
   image = "ForceFieldNoPassDeployableImage";
   pickUpName = "a force field";
   heatSignature = 0;
   emap = true;
};

//////////////////////   ForceField

function ForceFieldDeployable::onPickup(%this, %obj, %shape, %amount)
{
   // created to prevent console errors
}

//////////////////////   ForceField No pass

function ForceFieldNoPassDeployable::onPickup(%this, %obj, %shape, %amount)
{
   // created to prevent console errors
}

//////////////////////   ForceField

function DeployedForceField::onDestroyed(%this, %obj, %prevState)
{
   $TeamDeployedCount[%obj.team, ForceFieldDeployable]--;
   %obj.field.pzone.schedule(480, "delete");
   %obj.field.schedule(490, "delete");
   %obj.schedule(500, "delete");
   %obj.trigger.schedule(490, "delete"); // new trigger

}

//////////////////////   ForceField No pass

function DeployedForceFieldNoPass::onDestroyed(%this, %obj, %prevState)
{
   $TeamDeployedCount[%obj.team, ForceFieldNoPassDeployable]--;
   %obj.field.pzone.schedule(480, "delete");
   %obj.field.schedule(490, "delete");
   %obj.schedule(500, "delete");
}

//////////////////////   ForceField

function ForceFieldDeployableImage::onDeploy(%item, %plyr, %slot)
{
   %mask = $TypeMasks::InteriorObjectType | $TypeMasks::PlayerObjectType | $TypeMasks::VehicleObjectType;
   %vec = %plyr.getEyeVector();
   %deplObj = Parent::onDeploy(%item, %plyr, %slot);
   %x1 = getWord(%vec, 0);
   %y1 = getWord(%vec, 1);
   %z1 = getWord(%vec, 2);
   %endpos =  VectorAdd(%item.surfacePt, "0 0 10");
   %res = containerRayCast(%item.surfacePt, %endpos, %mask, 0);
   if(%res)
      %zscale=VectorDist("0 0 " @ getword(%res,3),"0 0 " @ getword(%item.SurfacePt,2));
   else
      %zscale=10;
   %extra = %x1;
   %x2 = %y1;
   %y2 = %extra;
   %vec2 = %x2 * -1 SPC %y2 SPC 0;
   %vec3 = %x2 SPC %y2 * -1 SPC 0;
   %initpos = VectorAdd(%item.SurfacePt, "0 0 " @ (%zscale / 2.4));
   %endpos =  VectorAdd(%initpos, VectorScale(%vec2, 10));
   %res = containerRayCast(%initpos, %endpos, %mask, 0);
   if(%res)
      %left=VectorDist(getword(%res,1) SPC getword(%res,2) @ " 0", getword(%item.SurfacePt, 0) SPC getword(%item.SurfacePt, 1) @ " 0");
   else
      %left=10;
   %endpos =  VectorAdd(%initpos, VectorScale(%vec3, 10));
   %res = containerRayCast(%initpos, %endpos, %mask, 0);
   if(%res)
      %right=VectorDist(getword(%res,1) SPC getword(%res,2) @ " 0", getword(%item.SurfacePt, 0) SPC getword(%item.SurfacePt, 1) @ " 0");
   else
      %right=10;
   %wid = %left + %right + 0.2;
   %av = %wid * 2 / 3;
   %movepos = VectorAdd(%item.SurfacePt, VectorScale(%vec2, (%left * 1.4)));
   %centerpos = VectorAdd(%movepos, VectorScale(%vec3, %av));
   %centerpos = VectorAdd(%centerpos, "0 0 " @ (%zscale / 2));
   if ((%x1 > 0) && (%y1 >= 0))
   {
      %zone = 0;
      %rad = mAtan(%x1, %y1);
   }
   else if((%x1 >= 0) && (%y1 < 0))
   {
      %zone = 1;
      %y1 *= -1;
      %rad = mAtan(%y1, %x1);
   }
   else if((%x1 < 0) && (%y1 <= 0))
   {
      %zone = 2;
      %y1 *= -1;
      %x1 *= -1;
      %rad = mAtan(%x1, %y1);
   }
   else if((%x1 <= 0) && (%y1 > 0))
   {
      %zone = 3;
      %x1 *= -1;
      %rad = mAtan(%y1, %x1);
   }
   %angle = mRadtoDeg(%rad);
   if (%zone == 1)
      %angle += 90;
   else if (%zone == 2)
      %angle += 180;
   else if (%zone == 3)
      %angle += 270;

   %rot = " 0 0 1 " @ %angle;
   %pos = getWords(%deplObj.getTransform(), 0, 2);
   %deplObj.field = new ForceFieldBare()
   {
      position = %movepos;
      rotation = %rot;
      scale = %wid @ " 0.02 " @ %zscale;
      dataBlock = "DeployedForceField2";
      parent = %deplObj;
      team = %plyr.team;
   };
   %deplObj.field.active = true;
   %deplObj.field.setSelfPowered();
   MissionCleanup.add(%deplObj.field);
   %deplObj.setTransform(%centerpos);
   %deplObj.team = %plyr.team;
   %deplObj.field.team = %plyr.team;
   %deplObj.owner = %plyr.client;
   %deplObj.field.owner = %plyr.client;
   if(%deplObj.field.getTarget() != -1)
      setTargetSensorGroup(%deplObj.field.getTarget(), %plyr.team);
   %deplObj.zscale = %zscale / 2;
   //new code to allow the forcefield to powerdown and up...
   %x1 = getWord(%vec, 0);
   %y1 = getWord(%vec, 1);
   %vec = VectorNormalize(%x1 * -1 SPC %y1 * -1 @ " 0");
   %movepos = VectorAdd(%movePos, VectorScale(%vec, 0.5));
   %movepos = VectorAdd(%movePos, VectorScale(%vec2, 0.5));
   %movepos = VectorAdd(%movePos, "0 0 -0.5");
   %deplObj.trigger = new Trigger()
   {
      position = %movepos;
      rotation = %rot;
      scale    = %wid + 1 @ " 1 " @ %zscale + 1;
      dataBlock = DeployableForceFieldTrigger;
      polyhedron = "0 1 0 1 0 0 0 -1 0 0 0 1";
      team = %plyr.team;
   };
   MissionCleanup.add(%deplObj.trigger);
   %deplObj.trigger.owner = %deplObj;
   %deplObj.trigger.Fcount = 0;

}

//////////////////////   ForceField No pass

function ForceFieldNoPassDeployableImage::onDeploy(%item, %plyr, %slot)
{
   %mask = $TypeMasks::InteriorObjectType | $TypeMasks::PlayerObjectType | $TypeMasks::VehicleObjectType;
   %vec = %plyr.getEyeVector();
   %deplObj = Parent::onDeploy(%item, %plyr, %slot);
   %x1 = getWord(%vec, 0);
   %y1 = getWord(%vec, 1);
   %z1 = getWord(%vec, 2);
   %endpos =  VectorAdd(%item.surfacePt, "0 0 10");
   %res = containerRayCast(%item.surfacePt, %endpos, %mask, 0);
   if(%res)
      %zscale=VectorDist("0 0 " @ getword(%res,3),"0 0 " @ getword(%item.SurfacePt,2));
   else
      %zscale=10;
   %extra = %x1;
   %x2 = %y1;
   %y2 = %extra;
   %vec2 = %x2 * -1 SPC %y2 SPC 0;
   %vec3 = %x2 SPC %y2 * -1 SPC 0;
   %initpos = VectorAdd(%item.SurfacePt, "0 0 " @ (%zscale / 2.4));
   %endpos =  VectorAdd(%initpos, VectorScale(%vec2, 10));
   %res = containerRayCast(%initpos, %endpos, %mask, 0);
   if(%res)
      %left=VectorDist(getword(%res,1) SPC getword(%res,2) @ " 0", getword(%item.SurfacePt, 0) SPC getword(%item.SurfacePt, 1) @ " 0");
   else
      %left=10;
   %endpos =  VectorAdd(%initpos, VectorScale(%vec3, 10));
   %res = containerRayCast(%initpos, %endpos, %mask, 0);
   if(%res)
      %right=VectorDist(getword(%res,1) SPC getword(%res,2) @ " 0", getword(%item.SurfacePt, 0) SPC getword(%item.SurfacePt, 1) @ " 0");
   else
      %right=10;
   %wid = %left + %right + 0.2;
   %av = %wid * 2 / 3;
   %movepos = VectorAdd(%item.SurfacePt, VectorScale(%vec2, (%left * 1.4)));
   %centerpos = VectorAdd(%movepos, VectorScale(%vec3, %av));
   %centerpos = VectorAdd(%centerpos, "0 0 " @ (%zscale / 2));
   if ((%x1 > 0) && (%y1 >= 0))
   {
      %zone = 0;
      %rad = mAtan(%x1, %y1);
   }
   else if((%x1 >= 0) && (%y1 < 0))
   {
      %zone = 1;
      %y1 *= -1;
      %rad = mAtan(%y1, %x1);
   }
   else if((%x1 < 0) && (%y1 <= 0))
   {
      %zone = 2;
      %y1 *= -1;
      %x1 *= -1;
      %rad = mAtan(%x1, %y1);
   }
   else if((%x1 <= 0) && (%y1 > 0))
   {
      %zone = 3;
      %x1 *= -1;
      %rad = mAtan(%y1, %x1);
   }
   %angle = mRadtoDeg(%rad);
   if (%zone == 1)
      %angle += 90;
   else if (%zone == 2)
      %angle += 180;
   else if (%zone == 3)
      %angle += 270;

   %rot = " 0 0 1 " @ %angle;
   %pos = getWords(%deplObj.getTransform(), 0, 2);
   %deplObj.field = new ForceFieldBare()
   {
      position = %movepos;
      rotation = %rot;
      scale = %wid @ " 0.02 " @ %zscale;
      dataBlock = "DeployedForceField3";  // was 2
      parent = %deplObj;
      team = %plyr.team;
   };
   %deplObj.field.active = true;
   %deplObj.field.setSelfPowered();
   MissionCleanup.add(%deplObj.field);
   %deplObj.setTransform(%centerpos);
   %deplObj.team = %plyr.team;
   %deplObj.field.team = %plyr.team;
   %deplObj.owner = %plyr.client;
   %deplObj.field.owner = %plyr.client;
   if(%deplObj.field.getTarget() != -1)
      setTargetSensorGroup(%deplObj.field.getTarget(), %plyr.team);
   %deplObj.zscale = %zscale / 2;
}

///////////// ForceField

function DeployedForceField2::onAdd(%data, %obj)
{
   Parent::onAdd(%data, %obj);
   for (%i=0; %i < PZones.getCount(); %i++)
   {
      if (PZones.getObject(%i).ffield == %obj)
         %obj.pzone = PZones.getObject(%i);
   }
}

///////////// ForceField NoPass

function DeployedForceField3::onAdd(%data, %obj)
{
   Parent::onAdd(%data, %obj);
   for (%i=0; %i < PZones.getCount(); %i++)
   {
      if (PZones.getObject(%i).ffield == %obj)
         %obj.pzone = PZones.getObject(%i);
   }
}

///////////// ForceField

function DeployedForceField2::damageObject(%data, %targetObject, %sourceObject, %position, %amount, %damageType)
{
   %targetObject.parent.getDataBlock().damageObject(%targetObject.parent, %sourceObject, %position, %amount, %damageType);
}

///////////// ForceField NoPass

function DeployedForceField3::damageObject(%data, %targetObject, %sourceObject, %position, %amount, %damageType)
{
   %targetObject.parent.getDataBlock().damageObject(%targetObject.parent, %sourceObject, %position, %amount, %damageType);
}

function ForceFieldBare::isMounted()
{

}
datablock TriggerData(DeployableForceFieldTrigger)
{
   tickPeriodMS = 1900; // was 30
};

function DeployableForceFieldTrigger::onEnterTrigger(%data, %obj, %colObj)
{
   %obj.Fcount++;
   if (%colObj.getDatablock().className !$= "Armor" || %colObj.getState() $= "Dead")
      return;

   if (%colObj.team == %obj.team)
   {
      %obj.owner.field.open();
      %obj.owner.playAudio(0, ForceFieldDownSound);
      %obj.owner.field.pzone.deactivate();
      }
}

function DeployableForceFieldTrigger::onLeaveTrigger(%data, %obj, %colObj)
{
   %obj.Fcount--;
   if (%obj.Fcount == 0)
   {
      %obj.owner.field.close();
      %obj.owner.playAudio(0, ForceFieldUPSound);
      %obj.owner.field.pzone.activate();
     }
}

function DeployableForceFieldTrigger::onTickTrigger(%data, %obj)
{
}

///////Forcefield powerup and powerdown sounds.......

datablock EffectProfile(ForceFieldUPEffect)
{
   effectname = "powered/vehicle_screen_off";
   minDistance = 2.5;
   maxDistance = 5.0;
};

datablock AudioProfile(ForceFieldUPSound)
{
   filename    = "fx/powered/vehicle_screen_off.wav";
   description = AudioClose3d;
   preload = true;
   effect = ForceFieldUPEffect;
};
////////////////////////////////////////////////////
datablock EffectProfile(ForceFieldDownEffect)
{
   effectname = "powered/vehicle_screen_on";
   minDistance = 2.5;
   maxDistance = 5.0;
};

datablock AudioProfile(ForceFieldDownSound)
{
   filename    = "fx/powered/vehicle_screen_on.wav";
   description = AudioClose3d;
   preload = true;
   effect = ForceFieldDownEffect;
};


// --------------------------------------------
// defender Designator

//$TeamDeployableMax[DefenderDesignator] = 3;
//$TeamDeployableMin[DefenderDesignator] = 3;

datablock ShapeBaseImageData(DefenderDesignatorImage)
{
   mass = 15;

   shapeFile = "pack_deploy_turreti.dts";
   item = DefenderDesignator;
   mountPoint = 1;
   offset = "0 0 0";

   stateName[0] = "Idle";
   stateTransitionOnTriggerDown[0] = "Activate";

   stateName[1] = "Activate";
   stateScript[1] = "onActivate";
   stateTransitionOnTriggerUp[1] = "Idle";

   emap = true;

   maxDepSlope = 360;
   deploySound = TurretDeploySound;

   minDeployDis                       =  0.5;
   maxDeployDis                       =  5.0;  //meters from body
};

datablock ItemData(DefenderDesignator)
{
   className = Pack;
   catagory = "Deployables";
   shapeFile = "pack_deploy_turreti.dts";
   mass = 3.0;
   elasticity = 0.2;
   friction = 0.6;
   pickupRadius = 1;
   rotate = false;
   image = "DefenderDesignatorImage";
   pickUpName = "a defender designator";

   emap = true;
};

function DefenderDesignatorImage::onDeploy(%item, %plyr, %slot)
{
   if(%item.item $= "MotionSensorDeployable" || %item.item $= "PulseSensorDeployable")
   {
      %plyr.deploySensors--;
      %plyr.client.updateSensorPackText(%plyr.deploySensors);
      if(%plyr.deploySensors <= 0)
      {
         // take the deployable off the player's back and out of inventory
         %plyr.unmountImage(%slot);
         %plyr.decInventory(%item.item, 1);
      }
   }
   else
   {
      // take the deployable off the player's back and out of inventory
      %plyr.unmountImage(%slot);
      %plyr.decInventory(%item.item, 1);
   }

   // create the actual deployable
   %rot = %item.getInitialRotation(%plyr);
   if(%item.deployed.className $= "DeployedTurret")
      %className = "Turret";
   else
      %className = "StaticShape";

   %deplObj = new (%className)() {
      dataBlock = %item.deployed;
   };


   // set orientation
   if(%className $= "Turret")
      %deplObj.setDeployRotation(%item.surfacePt, %item.surfaceNrm);
   else
      %deplObj.setTransform(%item.surfacePt SPC %rot);

   // set the recharge rate right away
   if(%deplObj.getDatablock().rechargeRate)
      %deplObj.setRechargeRate(%deplObj.getDatablock().rechargeRate);

   // set team, owner, and handle
   %deplObj.team = %plyr.client.Team;
   %deplObj.owner = %plyr.client;

   // set the sensor group if it needs one
   if(%deplObj.getTarget() != -1)
      setTargetSensorGroup(%deplObj.getTarget(), %plyr.client.team);

   // place the deployable in the MissionCleanup/Deployables group (AI reasons)
   addToDeployGroup(%deplObj);

   //let the AI know as well...
   AIDeployObject(%plyr.client, %deplObj);

   // play the deploy sound
   serverPlay3D(%item.deploySound, %deplObj.getTransform());

   // increment the team count for this deployed object

   $TeamDeployedCount[%plyr.team, "DefenderDesignator"]++;
   %deplObj.deploy();
   return %deplObj;
}

function DefenderDesignatorImage::getInitialRotation(%item, %plyr)
{
   %surfaceAngle = getTerrainAngle(%item.surfaceNrm);
   if(%surfaceAngle > 155)
      %item.deployed = DefenderDesignatorCeilingIndoor;
   else if(%surfaceAngle > 45)
      %item.deployed = DefenderDesignatorWallIndoor;
   else
      %item.deployed = DefenderDesignatorFloorIndoor;
}

function DefenderDesignatorImage::onPickup(%this, %obj, %shape, %amount)
{
   // created to prevent console errors
}

function DefenderDesignatorWallIndoor::onDestroyed(%this, %obj, %prevState)
{
     Parent::onDestroyed(%this, %obj, %prevState);
     $TeamDeployedCount[%obj.team, "DefenderDesignator"]--;
     %obj.schedule(750, "delete");
}

function DefenderDesignatorFloorIndoor::onDestroyed(%this, %obj, %prevState)
{
     Parent::onDestroyed(%this, %obj, %prevState);
     $TeamDeployedCount[%obj.team, "DefenderDesignator"]--;
     %obj.schedule(750, "delete");
}

function DefenderDesignatorCeilingIndoor::onDestroyed(%this, %obj, %prevState)
{
     Parent::onDestroyed(%this, %obj, %prevState);
     $TeamDeployedCount[%obj.team, "DefenderDesignator"]--;
     %obj.schedule(750, "delete");
}

//====================================== Det Pack
//$TeamDeployableMax[DetPack] = 3;

datablock ItemData(DetBomb)
{
   shapeFile = "stackable3s.dts";
   explosion = AnExplosion;
   underwaterExplosion = AnUWExplosion;
   mass = 1.2;
   elasticity = 0.1;
   friction = 0.9;
   rotate = false;
   pickupRadius = 0;
   noTimeout = true;
   maxDamage = 1.0;
   kickBackStrength    = 4000;

   computeCRC = true;
};

function detonateDetBomb(%det)
{
     if(isObject(%det))
     %det.setDamageState(Destroyed);
}

function DetBomb::onEnterLiquid(%data, %obj, %coverage, %type)
{
   // lava types
   if(%type >=4 && %type <= 6)
   {
      if(%obj.getDamageState() !$= "Destroyed")
      {
         detonateDetBomb(%obj);
         return;
      }
   }

  Parent::onEnterLiquid(%data, %obj, %coverage, %type);
}

function DetBomb::onDestroyed(%this, %object, %lastState)
{
     %dmgRadius = 75;
     %dmgMod = 10.0;
     %expImpulse = 75000;
     %dmgType = $DamageType::Annihalator;

     RadiusExplosion(%object, %object.getPosition(), %dmgRadius, %dmgMod, %expImpulse, %object.sourceObject, %dmgType);

     %object.schedule(500, "delete");
     $TeamDeployedCount[%object.team, DetPack]--;
}

datablock ShapeBaseImageData(DetPackImage)
{
   mass = 20;

   shapeFile = "pack_deploy_turreti.dts";
   item = DetPack;
   mountPoint = 1;
   offset = "0 0 0";
   deployed = DetBomb;

   stateName[0] = "Idle";
   stateTransitionOnTriggerDown[0] = "Activate";

   stateName[1] = "Activate";
   stateScript[1] = "onActivate";
   stateTransitionOnTriggerUp[1] = "Idle";

   isLarge = true;
   emap = true;

   maxDepSlope = 60;
   deploySound = TurretDeploySound;

   minDeployDis                       =  0.5;
   maxDeployDis                       =  5.0;  //meters from body
};

datablock ItemData(DetPack)
{
   className = Pack;
   catagory = "Deployables";
   shapeFile = "pack_deploy_turreti.dts";
   mass = 3.0;
   elasticity = 0.2;
   friction = 0.6;
   pickupRadius = 1;
   rotate = false;
   image = "DetPackImage";
   pickUpName = "a det pack";
   heatSignature = 0;

   emap = true;
};

function DetPack::onPickup(%this, %obj, %shape, %amount)
{
   // created to prevent console errors
}

function DetPackImage::onDeploy(%item, %plyr, %slot)
{
     %plyr.unmountImage(%slot);
     %plyr.decInventory(%item.item, 1);

     %rot = %item.getInitialRotation(%plyr);

   %charge = new Item()
   {
      dataBlock = DetBomb;
   };
   
   MissionCleanup.add(%charge);
   %charge.sourceObject = %plyr;

   %charge.setTransform(%item.surfacePt SPC %rot);
   %charge.team = %plyr.client.Team;
   %charge.owner = %plyr.client;

     if(%charge.getTarget() != -1)
           setTargetSensorGroup(%charge.getTarget(), %plyr.client.team);

     addToDeployGroup(%charge);
     AIDeployObject(%plyr.client, %charge);
     serverPlay3D(%item.deploySound, %charge.getTransform());
     $TeamDeployedCount[%plyr.team, "DetPack"]++;     // just fine
     schedule(20000, 0, "detonateDetBomb", %charge);
     return %charge;
}

//====================================== Deployable Vehicle Pad
//====================================== Deployable Vehicle Pad

//$TeamDeployableMax[VehiclePadPack] = 1;

datablock StaticShapeData(DeployableVehicleStation) : StaticShapeDamageProfile
{
   className = Station;
   catagory = "Stations";
   shapeFile = "vehicle_pad_station.dts";
   maxDamage = 19;
   destroyedLevel = 19;
   disabledLevel = 18;
   explosion      = LargeAirVehicleExplosion;
	expDmgRadius = 10.0;
	expDamage = 0.4;
	expImpulse = 1500.0;
   dynamicType = $TypeMasks::StationObjectType;
	isShielded = true;
	energyPerDamagePoint = 100;
	maxEnergy = 100;
	rechargeRate = 0.31;
   humSound = StationVehicleHumSound;

   cmdCategory = "Support";
   cmdIcon = CMDVehicleStationIcon;
   cmdMiniIconName = "commander/MiniIcons/com_vehicle_pad_inventory";
   targetTypeTag = 'Deployable Vehicle Station';

   debrisShapeName = "debris_generic.dts";
   debris = StationDebris;
};

datablock StaticShapeData(DeployableVehiclePad)
{
//   className = "StaticShape";
//   dynamicType = $TypeMasks::DamageableItemObjectType;

   shapeFile = "vehicle_pad.dts";
   //shapeFile = "nexusbase.dts"; // dmiscf.dts, alternate
   maxDamage = 19;
   destroyedLevel = 19;
   disabledLevel = 18;
   explosion      = ShapeExplosion;
	expDmgRadius = 10.0;
	expDamage = 0.4;
	expImpulse = 1500.0;
   rechargeRate = 0.05;
   targetTypeTag = 'Deployable Vehicle Station';
};

function DeployableVehicleStation::onAdd(%this, %obj)
{
   Parent::onAdd(%this, %obj);

	%obj.setRechargeRate(%obj.getDatablock().rechargeRate);
   %trigger = new Trigger()
   {
      dataBlock = stationTrigger;
      polyhedron = "-0.75 0.75 0.0 1.5 0.0 0.0 0.0 -1.5 0.0 0.0 0.0 2.0";
   };
   MissionCleanup.add(%trigger);
   %trigger.setTransform(%obj.getTransform());
   %trigger.station = %obj;
   %obj.trigger = %trigger;
}

function DeployableVehicleStation::stationReady(%data, %obj)
{
   // Make sure none of the other popup huds are active:
   messageClient( %obj.triggeredBy.client, 'CloseHud', "", 'scoreScreen' );
   messageClient( %obj.triggeredBy.client, 'CloseHud', "", 'inventoryScreen' );

   //Display the Vehicle Station GUI
   commandToClient(%obj.triggeredBy.client, 'StationVehicleShowHud');
}

function DeployableVehicleStation::stationFinished(%data, %obj)
{
   //Hide the Vehicle Station GUI
	commandToClient(%obj.triggeredBy.client, 'StationVehicleHideHud');
}

function DeployableVehicleStation::getSound(%data, %forward)
{
   if(%forward)
      return "StationVehicleAcitvateSound";
   else
      return "StationVehicleDeactivateSound";
}

function DeployableVehicleStation::setPlayersPosition(%data, %obj, %trigger, %colObj)
{
   %vel = getWords(%colObj.getVelocity(), 0, 1) @ " 0";
   if((VectorLen(%vel) < 22) && (%obj.triggeredBy != %colObj))
   {
      %posXY = getWords(%trigger.getTransform(),0 ,1);
      %posZ = getWord(%trigger.getTransform(), 2);
      %rotZ =  getWord(%obj.getTransform(), 5);
      %angle =  getWord(%obj.getTransform(), 6);
	   %angle += 3.141592654;
      if(%angle > 6.283185308)
         %angle = %angle - 6.283185308;
      %colObj.setvelocity("0 0 0");
      %colObj.setTransform(%posXY @ " " @ %posZ + 0.2 @ " " @ "0 0 "  @ %rotZ @ " " @ %angle );//center player on object
      return true;
   }
   return false;
}

function DeployableVehiclePad::onAdd(%this, %obj)
{
   Parent::onAdd(%this, %obj);

	%obj.ready = true;
   %obj.setRechargeRate(%obj.getDatablock().rechargeRate);
   %xform = %obj.getSlotTransform(0);
   %pos = getWords(%xform, 0, 2);
   %rot = getWords(%xform, 3, 5);
   %angle = (getWord(%xform, 6) * 180) / 3.14159;

   %sv = new StaticShape() {
	   scale = "1 1 1";
      dataBlock = StationVehicle;
	   lockCount = "0";
	   homingCount = "0";
	   team = %obj.team;
      position = %pos;
      rotation = %rot @ " " @ %angle;
	};
     if(%sv.getTarget() != -1)
           setTargetSensorGroup(%sv.getTarget(), %obj.team);

   MissionCleanup.add(%sv);
   %sv.getDataBlock().gainPower(%sv);
   %sv.pad = %obj;
   %obj.station = %sv;
   %sv.trigger.mainObj = %obj;
   %sv.trigger.disableObj = %sv;

   //Remove unwanted vehicles
   if(%obj.scoutVehicle !$= "Removed")
	 %sv.vehicle[scoutvehicle] = true;
   if(%obj.SuicideFlyer !$= "Removed")
	   %sv.vehicle[SuicideFlyer] = true;
   if(%obj.scoutFlyer !$= "Removed")
	 %sv.vehicle[scoutFlyer] = true;
   if(%obj.bomberFlyer !$= "Removed")
	 %sv.vehicle[bomberFlyer] = true;
   if(%obj.hapcFlyer !$= "Removed")
   	 %sv.vehicle[hapcFlyer] = true;
   if(%obj.hoverBike !$= "Removed")
   	%sv.vehicle[hoverBike] = true;
   	%sv.vehicle[ATV2] = true;
}

function StationVehicle::onDestroyed(%data, %obj, %prevState)
{
   if(%obj.isFake)
   {
      %obj.trigger.delete();
      %obj.pad.setDamageState(Destroyed);
      %obj.schedule(700, "delete");
   }
   Parent::onDestroyed(%data, %obj, %prevState);
}

function DeployableVehiclePad::onEndSequence(%data, %obj, %thread)
{
   if(%thread == $ActivateThread)
   {
      %obj.ready = true;
      %obj.stopThread($ActivateThread);
   }
   Parent::onEndSequence(%data, %obj, %thread);
}

function DeployableVehiclePad::gainPower(%data, %obj)
{
   %obj.station.setSelfPowered();
   Parent::gainPower(%data, %obj);
}

function DeployableVehiclePad::losePower(%data, %obj)
{
   %obj.station.clearSelfPowered();
   Parent::losePower(%data, %obj);
}

datablock ShapeBaseImageData(VehiclePadPackImage)
{
   mass = 10;
   emap = true;

   shapeFile = "pack_deploy_inventory.dts";
   item = VehiclePadPack;
   mountPoint = 1;
   offset = "0 0 0";
   heatSignature = 0;
   deployed = DeployableVehiclePad;

   stateName[0] = "Idle";
   stateTransitionOnTriggerDown[0] = "Activate";

   stateName[1] = "Activate";
   stateScript[1] = "onActivate";
   stateTransitionOnTriggerUp[1] = "Idle";

   maxDepSlope = 30;
   deploySound = StationDeploySound;

   minDeployDis                       =  0.5;
   maxDeployDis                       =  5.0;  //meters from body

};

datablock ItemData(VehiclePadPack)
{
   className = Pack;
   catagory = "Deployables";
   shapeFile = "pack_deploy_inventory.dts";
   mass = 3.0;
   elasticity = 0.2;
   friction = 0.6;
   pickupRadius = 1;
   rotate = false;
   image = "VehiclePadPackImage";
   pickUpName = "a deployable vehicle pad";
   heatSignature = 0;

   emap = true;
};

function VehiclePadPack::onPickup(%this, %obj, %shape, %amount)
{
   // created to prevent console errors
}
datablock StaticShapeData(VehiclePadTop) : StaticShapeDamageProfile
{
   //className = "StaticShape";
   className = "VAirBase";
   dynamicType = $TypeMasks::StaticObjectType;
   //shapeFile = "xmiscf.dts";   // stackable2l
   shapeFile = "nexusbase.dts"; // dmiscf.dts, alternate

   maxDamage = 19;
   destroyedLevel = 19;
   disabledLevel = 18;
   explosion = VehicleBombExplosion;

   targetNameTag = 'Vehicle';
   targetTypeTag = 'Base';

   debrisShapeName = "debris_generic_small.dts";
   debris = DeployableDebris;
   heatSignature = 0;
};

datablock StaticShapeData(VehiclePadBase) : StaticShapeDamageProfile
{
   //className = "StaticShape";
   className = "VAirBase";
   dynamicType = $TypeMasks::StaticObjectType;
   //shapeFile = "xmiscf.dts";   // stackable2l
   shapeFile = "NexusCap.dts";

   maxDamage = 19;
   destroyedLevel = 19;
   disabledLevel = 18;
   explosion = VehicleBombExplosion;

   targetNameTag = 'Vehicle';
   targetTypeTag = 'Base';

   debrisShapeName = "debris_generic_small.dts";
   debris = DeployableDebris;
   heatSignature = 0;
};

function Deploy::VehiclePadMessage(%this, %obj, %slot)
{
commandToClient( %obj.client, 'BottomPrint', "<color:FFFF00>You deployed a vehicle base.<spop>", 3, 1);
%obj.playAudio(0, StationDeploySound);
}

function VehiclePadPackImage::onDeploy(%item, %plyr, %slot)
{
      %item.surfacePt = VectorAdd(%item.surfacePt, "0 0 7"); // was 0 0 40
      // take the deployable off the player's back and out of inventory
      %plyr.unmountImage(%slot);
      %plyr.decInventory(%item.item, 1);

// create the actual deployable
      %rot = %item.getInitialRotation(%plyr);
      %deplObj = new StaticShape()
     {
      dataBlock = %item.deployed;
//      scale = "1 1 0.75";
     };
     %deplObjPad = new StaticShape()
     {
      scale = "21 21 4";
      dataBlock = "VehiclePadBase";
      team = %plyr.client.team;
     };
     %deplObjPad.parent = %deplObj;

     //%deplObjTop = new StaticShape()
     //{
     // scale = "12 12 2";
     // dataBlock = "VehiclePadTop";
     //  team = %plyr.client.team;
     //};
     //%deplObjTop.parent = %deplObj;

     %deplObjPad.parent = %deplObj;

     %deplObj.setTransform(modifyTri(%item.surfacePt, "0 2.5 0.5") SPC "0 0 1 3.14");
     %deplObjPad.setTransform(modifyTri(%item.surfacePt, "0 0 0.5") SPC "0 1 0 0");
   //was    %deplObjTop.setTransform(modifyTri(%item.surfacePt, "0 0 25.5") SPC "0 1 0 0");
     //%deplObjTop.setTransform(modifyTri(%item.surfacePt, "0 0 19.5") SPC "0 1 0 0");

   // set the recharge rate right away
   if(%deplObj.getDatablock().rechargeRate)
      %deplObj.setRechargeRate(%deplObj.getDatablock().rechargeRate);

   // set team, owner, and handle
   %deplObj.team = %plyr.client.Team;
   %deplObj.owner = %plyr.client;

   // set the sensor group if it needs one
   if(%deplObj.getTarget() != -1)
      setTargetSensorGroup(%deplObj.getTarget(), %plyr.client.team);
   if(%deplObjPad.getTarget() != -1)
      setTargetSensorGroup(%deplObjPad.getTarget(), %plyr.client.team);
   //if(%deplObjTop.getTarget() != -1)
      //setTargetSensorGroup(%deplObjTop.getTarget(), %plyr.client.team);

   // place the deployable in the MissionCleanup/Deployables group (AI reasons)
   addToDeployGroup(%deplObj);

   //let the AI know as well...
   AIDeployObject(%plyr.client, %deplObj);

   // play the deploy sound
   serverPlay3D(%item.deploySound, %deplObj.getTransform());

   // increment the team count for this deployed object
   %deplObj.getDatablock().onAdd(%deplObj);
   MissionCleanup.add(%deplObj);
   MissionCleanup.add(%deplObjPad);
   //MissionCleanup.add(%deplObjTop);
   $TeamDeployedCount[%plyr.team, %item.item]++;
   %deplObj.deploy();
   %deplObj.setSelfPowered();

     %stationObj = new StaticShape()
     {
        dataBlock = StationInventory;
        team = %plyr.client.team;
     };

     //was  %stationObj.setTransform(modifyTri(%item.surfacePt, "10 -22 2") SPC "0 0 1 1.57");
     %stationObj.setTransform(modifyTri(%item.surfacePt, "10 -20 2") SPC "0 0 1 1.57");
     %stationObj.setSelfPowered();
     %stationObj.fake = true;
     %stationObj.parent = %deplObj;

   %stationObj.setRechargeRate(%stationObj.getDatablock().rechargeRate);     // ripped from station.cs
   %trigger = new Trigger()
   {
      dataBlock = stationTrigger;
      polyhedron = "-0.75 0.75 0.1 1.5 0.0 0.0 0.0 -1.5 0.0 0.0 0.0 2.3";
   };
   MissionCleanup.add(%stationObj);
   %trigger.setTransform(%stationObj.getTransform());

   %trigger.station = %stationObj;
   %trigger.mainObj = %stationObj;
   %trigger.disableObj = %stationObj;
   %stationObj.trigger = %trigger;

     %stationObj.team = %plyr.client.Team;
     %stationObj.owner = %plyr.client;

     if(%stationObj.getTarget() != -1)
           setTargetSensorGroup(%stationObj.getTarget(), %plyr.client.team);

     addToDeployGroup(%stationObj);
     AIDeployObject(%plyr.client, %stationObj);
     serverPlay3D(%item.deploySound, %stationObj.getTransform());
     %stationObj.deploy();
     if(%stationObj.getTarget() != -1)
           setTargetSensorGroup(%stationObj.getTarget(), %plyr.client.team);
     MissionCleanup.add(%stationObj);

     %stationObj2 = new StaticShape()
     {
        dataBlock = StationInventory;
        team = %plyr.client.team;
     };

     //was %stationObj2.setTransform(modifyTri(%item.surfacePt, "-10 -22 2") SPC "0 0 1 -1.57");
     %stationObj2.setTransform(modifyTri(%item.surfacePt, "-10 -20 2") SPC "0 0 1 -1.57");
     %stationObj2.setSelfPowered();
     %stationObj2.fake = true;
     %stationObj2.parent = %deplObj;

   %stationObj2.setRechargeRate(%stationObj2.getDatablock().rechargeRate);     // ripped from station.cs
   %trigger2 = new trigger()
   {
      dataBlock = stationtrigger;
      polyhedron = "-0.75 0.75 0.1 1.5 0.0 0.0 0.0 -1.5 0.0 0.0 0.0 2.3";
   };
   MissionCleanup.add(%stationObj2);
   %trigger2.setTransform(%stationObj2.getTransform());

   %trigger2.station = %stationObj2;
   %trigger2.mainObj = %stationObj2;
   %trigger2.disableObj = %stationObj2;
   %stationObj2.trigger = %trigger2;

     %stationObj2.team = %plyr.client.Team;
     %stationObj2.owner = %plyr.client;

     if(%stationObj2.getTarget() != -1)
           setTargetSensorGroup(%stationObj2.getTarget(), %plyr.client.team);

     addToDeployGroup(%stationObj2);

     AIDeployObject(%plyr.client, %stationObj2);

     serverPlay3D(%item.deploySound, %stationObj2.getTransform());
     //
     Deploy::VehiclePadMessage(%item, %plyr, %slot);
     //
     %stationObj2.deploy();
     if(%stationObj2.getTarget() != -1)
           setTargetSensorGroup(%stationObj2.getTarget(), %plyr.client.team);
     MissionCleanup.add(%stationObj2);

      %pta = vectorAdd(%item.surfacePt, "15.25 27.75 0.5");
      %ptb = vectorAdd(%item.surfacePt, "-15.25 27.75 0.5");
      %ptc = vectorAdd(%item.surfacePt, "15.25 -27.75 0.5");
      %ptd = vectorAdd(%item.surfacePt, "-15.25 -27.75 0.5");

      %vec1 = getVectorFromPoints(%pta, %ptb);
      %vec2 = getVectorFromPoints(%ptb, %ptd);
      %vec3 = getVectorFromPoints(%ptd, %ptc);
      %vec4 = getVectorFromPoints(%ptc, %pta);

      %rota = vectorToRotZ(%vec1);
      %rotb = vectorToRotZ(%vec2);
      %rotc = vectorToRotZ(%vec3);
      %rotd = vectorToRotZ(%vec4);

      %lena = getDistance3D(%pta, %ptb);
      %lenb = getDistance3D(%ptb, %ptd);
      %lenc = getDistance3D(%ptd, %ptc);
      %lend = getDistance3D(%ptc, %pta);
}

function DeployableVehiclePad::onDestroyed(%this, %obj, %prevState)
{
   if(%obj.fake)
   {
        Parent::onDestroyed(%this, %obj, %prevState);
        %obj.schedule(500, "delete");
        %obj.station.schedule(500, "delete");
   }
   else
   {
      $TeamDeployedCount[%obj.team, VehiclePadPack]--;
      %obj.schedule(500, "delete");
      %obj.station.schedule(500, "delete");

      InitContainerRadiusSearch(%obj.getPosition(), 45, $TypeMasks::StaticObjectType | $TypeMasks::StaticShapeObjectType | $TypeMasks::StationObjectType);
      while((%int = ContainerSearchNext()) != 0)
      {
         if(%int.parent && %int.parent == %obj)
         {
            if(isObject(%int.trigger))
               %int.trigger.delete();

            %int.setDamageState(Destroyed);
            %int.setDamageLevel(1000);
         }
      }

      InitContainerRadiusSearch(%obj.getPosition(), 45, $TypeMasks::ForceFieldObjectType | $TypeMasks::DamageableItemObjectType);
      while((%int = ContainerSearchNext()) != 0)
      {
         if(%int.parent && %int.parent == %obj)
         {
            %int.setPosition("-10000 -10000 -10000");
            %int.pz.setPosition(%int.getPosition());
      	   %int.getDatablock().losePower(%int);
	         %int.delete();
        }
      }
   }
}

function VehiclePadTop::onDestroyed(%this, %obj, %prevState)
{
   %obj.schedule(500, "delete");
   %obj.parent.setDamageState(Destroyed);
   //  working on
   //%stationObj.StationInventory.schedule(500, "delete");
   //%stationObj2.StationInventory.schedule(500, "delete");

}

function VehiclePadBase::onDestroyed(%this, %obj, %prevState)
{
   %obj.schedule(500, "delete");
   %obj.parent.setDamageState(Destroyed);
   //  working on
   //%stationObj.StationInventory.schedule(500, "delete");
   //%stationObj2.StationInventory.schedule(500, "delete");

}

function StationInventory::onDestroyed(%this, %obj, %prevState)
{
   if(%obj.fake)
   {
        Parent::onDestroyed(%this, %obj, %prevState);
        if(isObject(%obj.trigger))
           %obj.trigger.delete();

        if(!%obj.parent)
          $TeamDeployedCount[%obj.team, "DeployableInvHumanPack"]--;

       %obj.schedule(500, "delete");

       }
   else
        Parent::onDestroyed(%this, %obj, %prevState);
}

function VehiclePadPackImage::testObjectTooClose(%item)
{
   %mask =    ($TypeMasks::VehicleObjectType     | $TypeMasks::MoveableObjectType   |
               $TypeMasks::StaticShapeObjectType | $TypeMasks::ForceFieldObjectType |
               $TypeMasks::ItemObjectType        | $TypeMasks::TurretObjectType     |
               $TypeMasks::InteriorObjectType);
   InitContainerRadiusSearch( VectorAdd(%item.surfacePt, "0 0 7"), 20, %mask );   // was 0 0 40
   %test = containerSearchNext();
   if(!%test)
   {
      InitContainerRadiusSearch( VectorAdd(%item.surfacePt, "0 0 7"), 20, $TypeMasks::PlayerObjectType );
      %test = containerSearchNext();
      if (%test)
         %test = containerSearchNext();
   }
   return %test;

}

