//--------------------------------------------------------------------------
// Vehicle Phaser Module
//--------------------------------------------------------------------------

datablock ShapeBaseImageData(vehiclePhaserModImage)
{
   mass = 0;

   shapeFile  = "pack_barrel_mortar.dts";
   item       = vehiclePhaserMod;
   mountPoint = 1;
   offset     = "0 0 0";

	stateName[0] = "Idle";
	stateTransitionOnTriggerDown[0] = "Activate";

	stateName[1] = "Activate";
	stateScript[1] = "onActivate";
	stateTransitionOnTriggerUp[1] = "Deactivate";

	stateName[2] = "Deactivate";
	stateScript[2] = "onDeactivate";
	stateTransitionOnTimeOut[2] = "Idle";

	isLarge = true;
};

datablock ItemData(vehiclePhaserMod)
{
   className    = Pack;
   catagory     = "Packs";
   shapeFile    = "pack_barrel_mortar.dts";
   mass         = 1;
   elasticity   = 0.2;
   friction     = 0.6;
   pickupRadius = 2;
   rotate       = true;
   image        = "vehiclePhaserModImage";
	pickUpName = "an vehiclePhaser module";
};

function vehiclePhaserModImage::onActivate(%data, %obj, %slot)
{
   // search for a vehicle in player's LOS
   %eyeVec = VectorNormalize(%obj.getEyeVector());
   %srchRange = VectorScale(%eyeVec, 5.0); // look 5m for a vehicle base
   %plTm = %obj.getEyeTransform();
   %plyrLoc = firstWord(%plTm) @ " " @ getWord(%plTm, 1) @ " " @ getWord(%plTm, 2);
   %srchEnd = VectorAdd(%plyrLoc, %srchRange);
   %potVehicle = ContainerRayCast(%obj.getEyeTransform(), %srchEnd, $TypeMasks::VehicleObjectType);

   if(%potVehicle != 0)    // positon of the vehicle
   {
          if(%potVehicle.getDatablock().getName() $= "ScoutFlyer") // Shrike Filter
          {
             // Not already augmented...
		   messageClient(%obj.client, 'MsgAugMount', "\c2Changed Weapon barrel -> Shrike -> Phaser Compression Rifle");
		   serverPlay3D(AugmentVehicle, %potVehicle.getTransform());
             vehiclePhaserMod::ApplyMod(%data, %obj, %potVehicle);
          }
          else
          {
             messageClient(%obj.client, 'MsgNotVehicle', "\c2Error! You cannot change weapons on this vehicle.");
             %obj.setImageTrigger($BackpackSlot, false);
          }
   }
   else
   {
      // I don't see any vehicle
      messageClient(%obj.client, 'MsgNoVehicle', "\c2No vehicle within the 5m range.");
      %obj.setImageTrigger($BackpackSlot, false);
   }
}

function vehiclePhaserModImage::onDeactivate(%data, %obj, %slot)
{
	%obj.setImageTrigger($BackpackSlot, false);
}

function vehiclePhaserMod::onPickup(%this, %obj, %shape, %amount)
{
	// created to prevent console errors
}

//**************************************************************
// WEAPONS
//**************************************************************

datablock AudioProfile(vPCRFireSound)
{
   filename    = "fx/misc/shieldh1.wav";
   description = AudioDefault3d;
   preload = true;
   effect = BlasterFireEffect;
};

datablock TracerProjectileData(vPCRBolt)
{
   doDynamicClientHits = true;

   directDamage        = 0.15;
   directDamageType    = $DamageType::vPhaser;
   explosion           = "PCRExplosion";
   hasDamageRadius     = true;
   indirectDamage      = 0.1;
   damageRadius        = 12.0;
   kickBackStrength    = 250;
   radiusDamageType    = $DamageType::vPhaser;
   splash              = ChaingunSplash;

   sound 				= ChaingunProjectile;

   dryVelocity       = 325.0;
   wetVelocity       = 175.0;
   velInheritFactor  = 1.0;
   fizzleTimeMS      = 3000;
   lifetimeMS        = 3000;
   explodeOnDeath    = false;
   reflectOnWaterImpactAngle = 15.0;
   explodeOnWaterImpact      = false;
   deflectionOnWaterImpact   = 1.0;
   fizzleUnderwaterMS        = 3000;

   tracerLength    = 20.0;
   tracerAlpha     = true;
   tracerMinPixels = 6;
   tracerColor     = "0.05 0.6 0.8 0.768";
	tracerTex[0]  	 = "special/ELFLightning";
	tracerTex[1]  	 = "special/nonlingradient";
	tracerWidth     = 0.400;
   crossSize       = 0.300;
   crossViewAng    = 0.99;
   renderCross     = true;
};

datablock ShapeBaseImageData(ScoutPhaserPairImage)
{
   className = WeaponImage;
   shapeFile = "weapon_grenade_launcher.dts";
   item      = Chaingun;
   projectile = vPCRBolt;
   projectileType = TracerProjectile;

   mountPoint = 10;
   offset = ".95 0.6 -0.1";
   rotation = "0 1 0 -90";

   usesEnergy = true;
   useMountEnergy = true;
   // DAVEG -- balancing numbers below!
   minEnergy = 50;
   fireEnergy = 10;
   fireTimeout = 500;

   //--------------------------------------
   stateName[0]             = "Activate";
   stateSequence[0]         = "Activate";
   stateAllowImageChange[0] = false;
   stateTimeoutValue[0]        = 0.05;
   stateTransitionOnTimeout[0] = "Ready";
   stateTransitionOnNoAmmo[0]  = "NoAmmo";
   //--------------------------------------
   stateName[1]       = "Ready";
   stateSpinThread[1] = Stop;
   stateTransitionOnTriggerDown[1] = "Spinup";
   stateTransitionOnNoAmmo[1]      = "NoAmmo";
   //--------------------------------------
   stateName[2]               = "NoAmmo";
   stateTransitionOnAmmo[2]   = "Ready";
   stateSpinThread[2]         = Stop;
   stateTransitionOnTriggerDown[2] = "DryFire";
   //--------------------------------------
   stateName[3]         = "Spinup";
   stateSpinThread[3]   = SpinUp;
   stateTimeoutValue[3]          = 0.01;
   stateWaitForTimeout[3]        = false;
   stateTransitionOnTimeout[3]   = "Fire";
   stateTransitionOnTriggerUp[3] = "Spindown";
   //--------------------------------------
   stateName[4]             = "Fire";
   stateSpinThread[4]       = FullSpeed;
   stateRecoil[4]           = LightRecoil;
   stateAllowImageChange[4] = false;
   stateScript[4]           = "onFire";
   stateFire[4]             = true;
   stateSound[4]            = vPCRFireSound;
   // IMPORTANT! The stateTimeoutValue below has been replaced by fireTimeOut
   // above.
   stateTimeoutValue[4]          = 0.5;
   stateTransitionOnTimeout[4]   = "checkState";
   //--------------------------------------
   stateName[5]       = "Spindown";
   stateSpinThread[5] = SpinDown;
   stateTimeoutValue[5]            = 0.01;
   stateWaitForTimeout[5]          = false;
   stateTransitionOnTimeout[5]     = "Ready";
   stateTransitionOnTriggerDown[5] = "Spinup";
   //--------------------------------------
   stateName[6]       = "EmptySpindown";
//   stateSound[6]      = ChaingunSpindownSound;
   stateSpinThread[6] = SpinDown;
   stateTransitionOnAmmo[6]   = "Ready";
   stateTimeoutValue[6]        = 0.01;
   stateTransitionOnTimeout[6] = "NoAmmo";
   //--------------------------------------
   stateName[7]       = "DryFire";
   stateSound[7]      = ShrikeBlasterDryFireSound;
   stateTransitionOnTriggerUp[7] = "NoAmmo";
   stateTimeoutValue[7]        = 0.25;
   stateTransitionOnTimeout[7] = "NoAmmo";

   stateName[8] = "checkState";
   stateTransitionOnTriggerUp[8] = "Spindown";
   stateTransitionOnNoAmmo[8]    = "EmptySpindown";
   stateTimeoutValue[8]          = 0.01;
   stateTransitionOnTimeout[8]   = "ready";
};

datablock ShapeBaseImageData(ScoutPhaserImage) : ScoutPhaserPairImage
{
   offset = "-.95 0.6 -0.1";
   rotation = "0 1 0 90";
   stateScript[3]           = "onTriggerDown";
   stateScript[5]           = "onTriggerUp";
   stateScript[6]           = "onTriggerUp";
};

datablock ShapeBaseImageData(ScoutPhaserParam)
{
   mountPoint = 2;
   shapeFile = "turret_muzzlepoint.dts";

   projectile = vPCRBolt;
   projectileType = TracerProjectile;
};

function ScoutPhaserImage::onFire(%data,%obj,%slot)
{
   Parent::onFire(%data,%obj,%slot);
   %obj.setImageTrigger(2, true);
   %obj.setImageTrigger(3, true);
}

function ScoutPhaserPairImage::onFire(%data,%obj,%slot)
{
   Parent::onFire(%data,%obj,%slot);
   %obj.setImageTrigger(2, true);
   %obj.setImageTrigger(3, true);
}

function vehiclePhaserMod::ApplyMod(%datablock, %player, %vehicle)
{
     %player.setInventory("vehiclePhaserMod", 0);
     commandToClient(%player.client, 'endBomberSight');

     %vehicle.unmountImage(0);
     %vehicle.unmountImage(2);
     %vehicle.unmountImage(3);

     %vehicle.mountImage(ScoutPhaserParam, 0);
     %vehicle.mountImage(ScoutPhaserImage, 2);
     %vehicle.mountImage(ScoutPhaserPairImage, 3);
     %vehicle.nextWeaponFire = 2;
}
