//--------------------------------------------------------------------------
// Particle Beam Weapon
//--------------------------------------------------------------------------

datablock AudioProfile(PBWSwitchSound)
{
   filename    = "fx/misc/diagnostic_on.wav";
   description = AudioClosest3d;
   preload = true;
   effect = SniperRifleSwitchEffect;
};

datablock AudioProfile(PBWFireSound)
{
   filename    = "fx/misc/lightning_impact.wav";
   description = AudioClose3d;
   preload = true;
   effect = SniperRifleFireEffect;
};

datablock AudioProfile(PBWProjectileSound)
{
   filename    = "fx/powered/turret_aa_fire.wav";
   description = AudioClose3d;
   preload = true;
};

//--------------------------------------------------------------------------
// Explosion
//--------------------------------------
datablock AudioProfile(PBWExpSound)
{
   filename    = "fx/powered/turret_plasma_explode.wav";
   description = AudioClosest3d;
   preload = true;
};

datablock ShockwaveData(PBWShockwave)
{
   width = 3;
   numSegments = 32;
   numVertSegments = 7;
   velocity = 15;
   acceleration = 8000;
   lifetimeMS = 999;
   height = 0.5;
   verticalCurve = 0.375;

   mapToTerrain = false;
   renderBottom = true;
   orientToNormal = true;

   texture[0] = "special/shockwave5";
   texture[1] = "special/gradient";
   texWrap = 3.0;

   times[0] = 0.1;
   times[1] = 5.0;
   times[2] = 10.5;

   colors[0] = "0.6 0.6 1.0 1.0";
   colors[1] = "0.6 0.3 1.0 0.5";
   colors[2] = "0.0 0.0 1.0 0.0";
};

datablock ExplosionData(PBWExplosion)
{
   explosionShape = "effect_plasma_explosion.dts";
   soundProfile   = PBWExpSound;
   shockwave      = PBWShockwave;
   faceViewer     = true;
};


//--------------------------------------
// Projectile
//--------------------------------------
datablock SniperProjectileData(ParticleBeam)
{
   directDamage        = 0.75;
   velInheritFactor    = 1.0;
   faceViewer          = true;
   sound 			   = PBWProjectileSound;
   explosion           = "PBWExplosion";
   splash              = PlasmaSplash;
   directDamageType    = $DamageType::PBW;

   maxRifleRange       = 80000;
   rifleHeadMultiplier = 2;
   beamColor           = "0.1 1 0.1";
   fadeTime            = 6.0;

   startBeamWidth		  = 0.04;
   endBeamWidth 	     = 0.04;
   pulseBeamWidth 	  = 0.005;
   beamFlareAngle 	  = 3.0;
   minFlareSize        = 0.0;
   maxFlareSize        = 60.0;
   pulseSpeed          = 2000;
   pulseLength         = 0.4;

   lightRadius         = 2.0;
   lightColor          = "1.1 1 1.1";

   textures[0] = "special/ELFBeam";
   textures[1] = "special/ELFLightning";
   textureName[0]      = "special/ELFBeam";
   textureName[1]      = "special/ELFLightning";
};

datablock TargetProjectileData(PBWLaserProj)
{
   directDamage        	= 0.75;
   hasDamageRadius     	= false;
   indirectDamage      	= 0.0;
   damageRadius        	= 0.02;
   velInheritFactor    	= 1.0;

   maxRifleRange       	= 80000;
   beamColor           	= "0.1 1 0.1";

   startBeamWidth			= 0.04;
   pulseBeamWidth 	   = 0.005;
   beamFlareAngle 	   = 3.0;
   minFlareSize        	= 0.0;
   maxFlareSize        	= 60.0;
   pulseSpeed          	= 2000;
   pulseLength         	= 0.4;

   textureName[0]      	= "special/ELFLightning";
   textureName[1]      	= "special/flare";
   textureName[2]      	= "special/ELFBeam";
   textureName[3]      	= "special/flare";
};

datablock ItemData(PBW)
{
   className    = Weapon;
   catagory     = "Spawn Items";
   shapeFile    = "weapon_sniper.dts";
   image        = PBWImage;
   mass         = 1;
   elasticity   = 0.2;
   friction     = 0.6;
   pickupRadius = 2;
	pickUpName = "a particle beam weapon (PBW)";
};

datablock ShapeBaseImageData(PBWImage)
{
	className = WeaponImage;
   shapeFile = "weapon_sniper.dts";
   item = PBW;
   projectile = ParticleBeam;
   projectileType = SniperProjectile;
   offset = "0 0.65 0";

	usesEnergy = true;
	minEnergy = 40;

   stateName[0]                     = "Activate";
   stateTransitionOnTimeout[0]      = "ActivateReady";
   stateSound[0]                    = PBWSwitchSound;
   stateTimeoutValue[0]             = 0.5;
   stateSequence[0]                 = "Activate";

   stateName[1]                     = "ActivateReady";
   stateTransitionOnLoaded[1]       = "Ready";
   stateTransitionOnNoAmmo[1]       = "NoAmmo";

   stateName[2]                     = "Ready";
   stateTransitionOnNoAmmo[2]       = "NoAmmo";
   stateTransitionOnTriggerDown[2]  = "CheckWet";

   stateName[3]                     = "Fire";
   stateTransitionOnTimeout[3]      = "Reload";
   stateTimeoutValue[3]             = 2.0;
   stateFire[3]                     = true;
   stateAllowImageChange[3]         = false;
   stateSequence[3]                 = "Fire";
   stateScript[3]                   = "onFire";

   stateName[4]                     = "Reload";
   stateTransitionOnTimeout[4]      = "Ready";
   stateTimeoutValue[4]             = 1.0;
   stateAllowImageChange[4]         = false;

   stateName[5]                     = "CheckWet";
   stateTransitionOnWet[5]          = "DryFire";
   stateTransitionOnNotWet[5]       = "Fire";
   
   stateName[6]                     = "NoAmmo";
   stateTransitionOnAmmo[6]         = "Reload";
   stateTransitionOnTriggerDown[6]  = "DryFire";
   stateSequence[6]                 = "NoAmmo";
   
   stateName[7]                     = "DryFire";
   stateSound[7]                    = ShockLanceDryFireSound;
   stateTimeoutValue[7]             = 0.5;
   stateTransitionOnTimeout[7]      = "Ready";
};

function PBWImage::onFire(%data,%obj,%slot)
{
   if(!%obj.hasEnergyPack)
   {
      messageClient(%obj.client, 'MsgNoenPack', "\c2You need the energy pack to operate the PBW.");
      serverPlay3D(ShockLanceDryFireSound, %obj.getTransform());
      return;
   }

   %p = new (%data.projectileType)() {
      dataBlock        = %data.projectile;
      initialDirection = %obj.getMuzzleVector(%slot);
      initialPosition  = %obj.getMuzzlePoint(%slot);
      sourceObject     = %obj;
      damageFactor     = 6;
      sourceSlot       = %slot;
   };

   %obj.lastProjectile = %p;
   MissionCleanup.add(%p);
   serverPlay3D(PBWFireSound, %obj.getTransform());

   %t = new TargetProjectile()
   {
          dataBlock        = "PBWLaserProj";
          initialDirection = %obj.getMuzzleVector(%slot);
          initialPosition  = %obj.getMuzzlePoint(%slot);
          sourceObject     = %obj;
          sourceSlot       = %slot;
          vehicleObject    = 0;
   };
   MissionCleanup.add(%t);
   // AI hook
   if(%obj.client)
      %obj.client.projectile = %p;

   %obj.setEnergyLevel(%obj.getEnergyLevel() - 40);
   schedule(350, 0, "killit", %t);
}

