//--------------------------------------
// Mortar
//--------------------------------------

//--------------------------------------------------------------------------
// Projectile
//--------------------------------------
datablock GrenadeProjectileData(FlakShot)
{
   projectileShapeName = "mortar_projectile.dts";
   emitterDelay        = -1;
   directDamage        = 0.0;
   hasDamageRadius     = true;
   indirectDamage      = 1.0;
   damageRadius        = 20.0;
   radiusDamageType    = $DamageType::Mortar;
   kickBackStrength    = 150;

   explosion           = "MortarExplosion";
   underwaterExplosion = "UnderwaterMortarExplosion";
   velInheritFactor    = 1.0;
   splash              = MortarSplash;
   depthTolerance      = 10.0; // depth at which it uses underwater explosion
   
   baseEmitter         = GrenadeSmokeEmitter;
   bubbleEmitter       = GrenadeBubbleEmitter;
   
   grenadeElasticity = 0.15;
   grenadeFriction   = 0.4;
   armingDelayMS     = 2000;
   muzzleVelocity    = 480;
   drag              = 0.1;

   sound			 = MortarProjectileSound;

   hasLight    = true;
   lightRadius = 3;
   lightColor  = "1.0 1.0 1.0";
};

datablock ItemData(FlakCharge)
{
   shapeFile = "mortar_projectile.dts";
   explosion = MortarExplosion;
   underwaterExplosion = UnderwaterMortarExplosion;
   mass = 0.1;
   elasticity = 0.1;
   friction = 0.9;
   rotate = true;
   pickupRadius = 0;
//   noTimeout = true;
   maxDamage = 1.5;
};

//--------------------------------------------------------------------------
// Ammo
//--------------------------------------

datablock ItemData(FlakMortarAmmo)
{
   className = Ammo;
   catagory = "Ammo";
   shapeFile = "ammo_mortar.dts";
   mass = 1;
   elasticity = 0.2;
   friction = 0.6;
   pickupRadius = 2;
	pickUpName = "some flak ammo";
};

//--------------------------------------------------------------------------
// Weapon
//--------------------------------------

datablock ShapeBaseImageData(FlakMortarImage)
{
   className = WeaponImage;
   shapeFile = "weapon_mortar.dts";
   item = FlakMortar;
   ammo = FlakMortarAmmo;
   offset = "0 0 0";
   emap = true;

   stateName[0] = "Activate";
   stateTransitionOnTimeout[0] = "ActivateReady";
   stateTimeoutValue[0] = 0.5;
   stateSequence[0] = "Activate";
   stateSound[0] = MortarSwitchSound;

   stateName[1] = "ActivateReady";
   stateTransitionOnLoaded[1] = "Ready";
   stateTransitionOnNoAmmo[1] = "NoAmmo";

   stateName[2] = "Ready";
   stateTransitionOnNoAmmo[2] = "NoAmmo";
   stateTransitionOnTriggerDown[2] = "Fire";

   stateName[3] = "Fire";
   stateSequence[3] = "Recoil";
   stateTransitionOnTimeout[3] = "Reload";
   stateTimeoutValue[3] = 0.3;
   stateFire[3] = true;
//   stateRecoil[3] = LightRecoil;
   stateAllowImageChange[3] = false;
   stateScript[3] = "onFire";
//   stateSound[3] = MortarFireSound;

   stateName[4] = "Reload";
   stateTransitionOnNoAmmo[4] = "NoAmmo";
   stateTransitionOnTimeout[4] = "Ready";
   stateTimeoutValue[4] = 0.05;
   stateAllowImageChange[4] = false;
   stateSequence[4] = "Reload";
//   stateSound[4] = MortarReloadSound;

   stateName[5] = "NoAmmo";
   stateTransitionOnAmmo[5] = "Reload";
   stateSequence[5] = "NoAmmo";
   stateTransitionOnTriggerDown[5] = "DryFire";

   stateName[6]       = "DryFire";
   stateSound[6]      = MortarDryFireSound;
   stateTimeoutValue[6]        = 1.5;
   stateTransitionOnTimeout[6] = "NoAmmo";
};

datablock ItemData(FlakMortar)
{
   className = Weapon;
   catagory = "Spawn Items";
   shapeFile = "weapon_mortar.dts";
   image = FlakMortarImage;
   mass = 1;
   elasticity = 0.2;
   friction = 0.6;
   pickupRadius = 2;
	pickUpName = "a flak mortar";

   emap = true;
};

function enableFlak(%obj)
{
    %obj.play3d(MortarReloadSound);
    %obj.flakEnabled = true;
}

function flakTrigger(%obj)
{
    %flak = new Item()
    {
        dataBlock = FlakCharge;
        rotation = "0 0 1 " @ (getRandom() * 360);
    };
    MissionCleanup.add(%flak);

    %flak.setPosition(%obj.getPosition());
    %flak.sourceObject = %obj.sourceObject;
    %flak.setDamageState(Destroyed);

    %obj.delete();
}

function FlakCharge::onDestroyed(%this, %object, %lastState)
{
      RadiusExplosion(%object, %object.getPosition(), 20, 1, 2000, %object.sourceObject, $DamageType::Mortar);
//      schedule(500, 0, "killit", %object);
}

function FlakMortarImage::onMount(%data, %obj, %slot)
{
    %obj.flakEnabled = true;
    Parent::onMount(%data, %obj, %slot);
}

function FlakMortarImage::onFire(%data, %obj, %slot)
{
   %data.lightStart = getSimTime();

    if(isObject(%obj.lastMortar))
    {
        FlakTrigger(%obj.lastMortar);
        return;
    }

    if(!%obj.flakEnabled)
        return;

//   if( %obj.station $= "" && %obj.isCloaked() )
//   {
//      if( %obj.respawnCloakThread !$= "" )
//      {
//         Cancel(%obj.respawnCloakThread);
//         %obj.setCloaked( false );
//         %obj.respawnCloakThread = "";
//      }
//      else
//      {
//         if( %obj.getEnergyLevel() > 20 )
//         {
//            %obj.setCloaked( false );
//            %obj.reCloak = %obj.schedule( 500, "setCloaked", true );
//         }
//      }
//   }

      %p = new GrenadeProjectile() {
         dataBlock        = "FlakShot";
         initialDirection = %obj.getMuzzleVector(%slot);
         initialPosition  = %obj.getMuzzlePoint(%slot);
         sourceObject     = %obj;
         sourceSlot       = %slot;
         vehicleObject    = 0;
      };

   %obj.lastMortar = %p;
   MissionCleanup.add(%p);

   // AI hook
   if(%obj.client)
      %obj.client.projectile = %p;

    %obj.decInventory(%data.ammo,1);
    %obj.play3d(MortarFireSound);
    %obj.flakEnabled = false;
    schedule(2800, 0, "enableFlak", %obj);
}
