//--------------------------------------
// Starburst Cannon
//--------------------------------------

datablock ExplosionData(StarburstExplosion)
{
   soundProfile   = MortarExplosionSound;

   subExplosion[0] = MortarSubExplosion1;
   subExplosion[1] = MortarSubExplosion2;
   subExplosion[2] = MortarSubExplosion3;

   shakeCamera = true;
   camShakeFreq = "8.0 9.0 7.0";
   camShakeAmp = "100.0 100.0 100.0";
   camShakeDuration = 1.3;
   camShakeRadius = 25.0;
};

//--------------------------------------------------------------------------
// Projectile
//--------------------------------------
datablock LinearProjectileData(StarburstShell)
{
   projectileShapeName = "grenade.dts";
   emitterDelay        = 250;
   directDamage        = 0.0;
   hasDamageRadius     = true;
   indirectDamage      = 0.15;
   damageRadius        = 5.0;
   radiusDamageType    = $DamageType::Explosion;
   kickBackStrength    = 500;
   bubbleEmitTime      = 1.0;

   explosion           = "StarburstExplosion";
   splash              = MissileSplash;
   velInheritFactor    = 1.0;

   delayEmitter        = MissileFireEmitter;
   bubbleEmitter       = GrenadeBubbleEmitter;
   bubbleEmitTime      = 1.0;

   dryVelocity       = 80;
   wetVelocity       = 50;
   velInheritFactor  = 0.5;
   fizzleTimeMS      = 1500;
   lifetimeMS        = 1500;
   explodeOnDeath    = true;
   reflectOnWaterImpactAngle = 0;
   explodeOnWaterImpact      = false;
   deflectionOnWaterImpact   = 0.0;
   fizzleUnderwaterMS        = 1500;

   activateDelayMS = 200;

   hasLight    = true;
   lightRadius = 6.0;
   lightColor  = "0.175 0.175 0.5";
   
   expProj     = "PlasmaBomb";
   mortarCount = 15;
};

datablock GrenadeProjectileData(PlasmaBomb)
{
   projectileShapeName = "mortar_projectile.dts";
   emitterDelay        = -1;
   directDamage        = 0.0;
   hasDamageRadius     = true;
   indirectDamage      = 0.357;
   damageRadius        = 15.0;
   radiusDamageType    = $DamageType::Plasma;
   kickBackStrength    = 100;

   explosion           = "PlasmaBoltExplosion";
   underwaterExplosion = "UnderwaterGrenadeExplosion";
   velInheritFactor    = 0.5;
   splash              = MortarSplash;

   baseEmitter         = GrenadeSmokeEmitter;
   bubbleEmitter       = MortarBubbleEmitter;

   grenadeElasticity = 0.75;
   grenadeFriction   = 0.2;
   armingDelayMS     = 250;
   muzzleVelocity    = 63.7;
   drag              = 0.1;
   sound			 = GrenadeProjectileSound;

   hasLight    = true;
   lightRadius = 4;
   lightColor  = "0.05 0.2 0.05";

   hasLightUnderwaterColor = true;
   underWaterLightColor = "0.05 0.075 0.2";

};

function StarburstShell::onExplode(%data, %proj, %pos, %mod)
{
     %player = %proj.client;
     
     if(%player.StarburstMode == 0)
     {
          %projectile = "PlasmaBomb";
          %projectileType = "GrenadeProjectile";
     }
     else if(%player.StarburstMode == 1)
     {
          %projectile = "PlasmaBolt";
          %projectileType = "LinearFlareProjectile";
     }
     else if(%player.StarburstMode == 2)
     {
          %projectile = "DiscProjectile";
          %projectileType = "LinearProjectile";
     }
     else if(%player.StarburstMode == 3)
     {
          %projectile = "MitziBooster";
          %projectileType = "LinearFlareProjectile";
     }
     else if(%player.StarburstMode == 4)
     {
          %projectile = "DumbMissile";
          %projectileType = "SeekerProjectile";
     }

     for(%i = 0; %i < 40; %i++)
     {
      %projectileSpread = 2.88;
      %vector = "0 0 -1";
      %x = (getRandom() - 0.5) * 2 * 3.1415926 * %projectileSpread;
      %y = (getRandom() - 0.5) * 2 * 3.1415926 * %projectileSpread;
      %z = (getRandom() - 0.5) * 2 * 3.1415926 * %projectileSpread;
      %mat = MatrixCreateFromEuler(%x @ " " @ %y @ " " @ %z);
      %vector = MatrixMulVector(%mat, %vector);

      %p = new (%projectileType)()
      {
         dataBlock        = %projectile;
         initialDirection = %vector;
         initialPosition  = %pos;
         sourceObject     = %proj.sourceObject;
         sourceSlot       = -1;
         vehicleObject    = 0;
      };

      MissionCleanup.add(%p);
     }
     Parent::onExplode(%data, %proj, %pos, %mod);
}

//--------------------------------------------------------------------------
// Ammo
//--------------------------------------

datablock ItemData(StarburstAmmo)
{
   className = Ammo;
   catagory = "Ammo";
   shapeFile = "ammo_mortar.dts";
   mass = 1;
   elasticity = 0.2;
   friction = 0.6;
   pickupRadius = 2;
	pickUpName = "some starburst ammo";

   computeCRC = true;

};

//--------------------------------------------------------------------------
// Weapon
//--------------------------------------
datablock ItemData(Starburst)
{
   className = Weapon;
   catagory = "Spawn Items";
   shapeFile = "weapon_mortar.dts";
   image = StarburstImage;
   mass = 1;
   elasticity = 0.2;
   friction = 0.6;
   pickupRadius = 2;
	pickUpName = "a starburst cannon";

   emap = true;
};

datablock ShapeBaseImageData(StarburstImage)
{
   className = WeaponImage;
   shapeFile = "weapon_mortar.dts";
   item = Starburst;
   ammo = StarburstAmmo;
   armThread = lookms;
   emap = true;

   stateName[0] = "Activate";
   stateTransitionOnTimeout[0] = "ActivateReady";
   stateTimeoutValue[0] = 0.5;
   stateSequence[0] = "Activate";
   stateSound[0] = MortarSwitchSound;

   stateName[1] = "ActivateReady";
   stateTransitionOnLoaded[1] = "Ready";
   stateTransitionOnNoAmmo[1] = "NoAmmo";

   stateName[2] = "Ready";
   stateTransitionOnNoAmmo[2] = "NoAmmo";
   stateTransitionOnTriggerDown[2] = "Fire";
   stateSound[2] = MortarIdleSound;

   stateName[3] = "Fire";
   stateSequence[3] = "Recoil";
   stateTransitionOnTimeout[3] = "Reload";
   stateTimeoutValue[3] = 0.8;
   stateFire[3] = true;
   stateRecoil[3] = LightRecoil;
   stateAllowImageChange[3] = false;
   stateScript[3] = "onFire";
   stateSound[3] = MortarFireSound;

   stateName[4] = "Reload";
   stateTransitionOnNoAmmo[4] = "NoAmmo";
   stateTransitionOnTimeout[4] = "Ready";
   stateTimeoutValue[4] = 2.0;
   stateAllowImageChange[4] = false;
   stateSequence[4] = "Reload";
   stateSound[4] = MortarReloadSound;

   stateName[5] = "NoAmmo";
   stateTransitionOnAmmo[5] = "Reload";
   stateSequence[5] = "NoAmmo";
   stateTransitionOnTriggerDown[5] = "DryFire";

   stateName[6]       = "DryFire";
   stateSound[6]      = MortarDryFireSound;
   stateTimeoutValue[6]        = 1.5;
   stateTransitionOnTimeout[6] = "NoAmmo";
};

function StarburstImage::onFire(%data, %obj, %slot)
{
   %data.lightStart = getSimTime();

   %vehicle = 0;

     if(%obj.client.StarburstMode == 0)
          %ammoUse = 1;
     else if(%obj.client.StarburstMode == 1)
          %ammoUse = 1;
     else if(%obj.client.StarburstMode == 2)
          %ammoUse = 3;

     if(%ammoUse > %obj.getInventory(%data.ammo))
          return;
          
      %p = new LinearProjectile() {
         dataBlock        = "StarburstShell";
         initialDirection = %obj.getMuzzleVector(%slot);
         initialPosition  = %obj.getMuzzlePoint(%slot);
         sourceObject     = %obj;
         sourceSlot       = %slot;
         vehicleObject    = %vehicle;
      };

   if (isObject(%obj.lastProjectile) && %obj.deleteLastProjectile)
      %obj.lastProjectile.delete();

   %obj.lastProjectile = %p;
   %obj.deleteLastProjectile = %data.deleteLastProjectile;
   MissionCleanup.add(%p);

     %p.client = %obj.client;
     %p.client.player = %obj.client.player;
     %p.client.player.slot = %slot;
     %proj = %p.getDatablock();

   // AI hook
   if(%obj.client)
      %obj.client.projectile = %p;

   %obj.decInventory(%data.ammo,%ammoUse);
   return %p;
}
